/* Improve modeling of the Social Monthly Assistance (GMI), using eligibility 
	conditions. We aim to get the following estimates:
	
	1. Coverage in 1st quintile (poorest) (%)
	2. Benefits incidence (% benefits accruing to each quintile)
	3. Beneficiary incidence (% beneficiary accruing to each quintile)
	4. Adequacy of benefits (% income by quintile)
	5. Marginal Contributions to Poverty and Gini
	6. Number of beneficiaries: admin vs simulation
	7. Fiscal cost (admin vs simulation)
	
*/

cap program drop pov_1
program define pov_1 
	cap drop `3' s`3' vs`3' 
	gen `3' = 0
	gen s`3' = 0
	gen vs`3' = 0
	mata: st_view(y=.,.,"`1'",.)
	mata: st_view(p=.,.,"`2'",.)		
	mata: p1 =((y:<p):*(-(y:/p):+1):^0)
	mata: sp1=((y:<p):*(-(y:/p):+1):^1)
	mata: ap1=((y:<p):*(p:-y))		
	mata: vsp1=((y:<p):*(p-y))
	mata: st_store(., "`3'",.,     p1[,1])
	mata: st_store(., "s`3'",.,   sp1[,1])
	mata: st_store(., "vs`3'",., vsp1[,1])
end 	

cap program drop sumt 
program define sumt 
	summ `1'  [w=weight], meanonly
	di %18.0fc r(sum)	
end 

cap program drop esc_pitbg

program define esc_pitbg 
	tempvar above_min 
	gen `above_min' =  (ytp2_in<($min_sal*12*$mult_min))*($mult_all-1)+1
	tab `above_min'

	cap drop disab_t 
	egen disab_t = rmax(disab_f disab_m) 
	cap drop child_t
	egen child_t = rmax(child_f child_m) 

*Standard deduction for permantly disabled
	cap drop disab_allowance
	gen double disab_allowance = min(ytp2_in*$r_dis,$max_dis)*`above_min' if ph030==1 & ph020==1
	replace disab_allowance = 0 if disab_allowance==.

*2.3.2 Deduction for voluntary social, unemployment, health and life 
	*	insurance (max.% from the consolidated tax base)  NOT INCLUDED 
*2.3.3. Standard child deduction
	cap drop child_allowance
	gen double child_allowance =  0
	replace child_t =0 if child_t==.
	replace disab_t =0 if disab_t==.
	replace    child_allowance = min(${a_chd}*child_t, $max_chd)*`above_min' 
	replace    child_allowance = (max(0,child_allowance) + $dis_chd) if disab_t>0
	replace    child_allowance = 0 if child_allowance ==.

*2.3.4. Deduction of bequests NOT INCLUDED 

*  ----------2.4 Taxable income 
	cap drop ytp3_in 
	gen double ytp3_in = ytp2_in - disab_allowance - child_allowance
	replace ytp3_in =0 if ytp3_in==. | ytp3_in<0	

	cap drop   `1'_pitx_*
	gen double `1'_pitx_in = ytp3_in * $pit_rate 
	label var  `1'_pitx_in "PIT scenario 2 (individual)"

	percap `1'_pitx_in 
	rpayi  `1'_pitx_in 	
	gen `1'_pitx_ae = ((`1'_pitx_pc*hsize))/hx050
	
end 

cap program drop child_adj01
program define child_adj01 
// forval i = 4 (1) 5 {
	
	
	global mult_benm  = `1'
	tempvar benefmt00 
	gen     `benefmt00' =  (40*12)/EXR*$mult_benm if totchild==1
	replace `benefmt00' =  (90*12)/EXR*$mult_benm if totchild==2
	replace `benefmt00' = (135*12)/EXR*$mult_benm if totchild==3
	replace `benefmt00' = (145*12)/EXR*$mult_benm if totchild==4
	replace `benefmt00' = (145*12)/EXR*$mult_benm +((20*12)/EXR)*$mult_benm*(totchild-4) if totchild>4 & totchild<.
	
	tempvar inbenef hinbenef 
	egen `inbenef' = rsum(py100g py110g py120g py130g)
	bysort hhid: egen `hinbenef' = sum(`inbenef')
	cap drop famtestinc20_hh famtestinc20_pc
	egen famtestinc20_hh  = rsum(hy023 `hinbenef') 
	gen  famtestinc20_pc = famtestinc20_hh/hx040
	
	cap drop dt3_fmnc_in
	gen double dt3_fmnc_in = `benefmt00' if famtestinc20_pc<$miny_fam02 & memb_no==1
	
	replace    dt3_fmnc_in = `benefmt00'*.8 ///
	if inrange(famtestinc20_pc,$miny_fam02,$miny_fam03) & memb_no==1	
	tempvar widow widow_in_hhd
	gen `widow' = pb190==4 & (child_f>0 | child_m>0)	
	bysort hhid: egen `widow_in_hhd' = max(`widow')

	replace dt3_fmnc_in = `benefmt00' if lonep_hh>0  & memb_no==1 & `widow_in_hhd' ==1
	
	rpayi dt3_fmnc_in 
	replace dt3_fmnc_ri = 0 if hy053g==0 | hy053g==.
	replace dt3_fmnc_ri = 0 if hy052g>0 & hy052g<.
	replace dt3_fmnc_in=0 if dt3_fmnc_ri==0
	
	// sumt dt3_fmnc_ri  // 508,252  vs 344,000  /509217/		
	sumt dt3_fmnc_ri  // 306,524 vs 344,000 89%  /307027	
	sumt dt3_fmnc_in // 137322568 m vs 143  // 96%  /137.446142/	
	label var dt3_fmnc_in "Dir.Transfer: Monthly child allowance N-MT (individual)"	
	percap dt3_fmnc_in 
	
	foreach pc_var of varlist dt3_fmnc_pc  {
		local ae_var = subinstr("`pc_var'","pc","ae",1)
		local pc_lab : variable label `pc_var'
		local ae_lab = subinstr("`pc_lab'","Per capita","Adult equivalent",1)
		cap drop `ae_var'
		gen double  `ae_var' = ((`pc_var'*hsize))/hx050
		label var `ae_var' "`ae_lab'"
	}
	
// Estimate poverty and inequality --------------------------------------
	
	cap drop y*3_pc 
	cap drop y*3_ae 	
	
	gen double  yd3_pc = yd_pc - dtr_fmnc_pc + dt3_fmnc_pc + dtx_pitx_pc - `2'_pc 
	egen double yc3_pc = rsum(yd3_pc `tot_itx' `tot_sub')
	
	tempvar tot_itx tmp_yc tot_sub  tot_itxae tot_subae
	egen double `tot_itx'   = rsum(itx_vatx_pc  itx_oild_pc  itx_oili_pc  itx_beve_pc  itx_toba_pc)
	egen double `tot_itxae' = rsum(itx_vatx_ae  itx_oild_ae  itx_oili_ae  itx_beve_ae  itx_toba_ae)
		replace `tot_itx'   = `tot_itx'*-1
		replace `tot_itxae' = `tot_itxae'*-1
		
	egen double `tot_sub' = rsum(sub*pc)
	egen double `tot_subae' = rsum(sub*ae)
	
	gen double  yd3_ae = yd_ae - dtr_fmnc_ae + dt3_fmnc_ae + dtx_pitx_ae - `2'_ae 
	egen double yc3_ae = rsum(yd3_ae `tot_itxae' `tot_subae')
	
	label var yd3_pc "Disposable income Scen 3 (per capita)"
	label var yc3_pc "Consumable Income Scen 3 (per capita)"	
	
	display "total ****"
apoverty yc*_ae [w=weight], varpl(pline_mod)
	
	display "children ***"
	apoverty yc*_ae [w=weight] if child_==1, varpl(pline_mod)
	local a0=  real(r(head_2))
	di "`i'"
	qui summ dtr_fmnc_in [w=weight], meanonly
	local a=r(sum)
	qui summ dt3_fmnc_in [w=weight], meanonly
	local b=r(sum)
	local a1 = (`b'-`a')/1000000
	local b1 = ((`b'-`a')/`a')*100		
	
	mat resa  = ($mult_mchi, $mult_benm, `a0' , `a1', `b1')		
	mat res = (nullmat(res) \ resa)	
end 

cap program drop child_adj02

program define child_adj02
syntax , [First(integer 50) Second(integer 110) Third(integer 165) ///
	Fourth(integer 175) Extra(integer 20) Inc1(integer 510) ///
	Inc2(integer 610)]
local first  `first'
local second `second'
local third  `third'
local fourth `fourth'
local extra  `extra'
local inc01  `inc1'
local inc02  `inc2'

local miny_fam02 = (`inc01'/EXR)*12		  // 100%
local miny_fam03 = (`inc02'/EXR)*12		  // 80%
	
tempvar benefmt00 
gen     `benefmt00' = (`first' *12)/EXR if totchild==1
replace `benefmt00' = (`second'*12)/EXR if totchild==2
replace `benefmt00' = (`third' *12)/EXR if totchild==3
replace `benefmt00' = (`fourth'*12)/EXR if totchild==4
replace `benefmt00' = (`fourth'*12)/EXR +((`extra'*12)/EXR)*(totchild-4) if totchild>4 & totchild<.
	
tempvar inbenef hinbenef 
egen `inbenef' = rsum(py100g py110g py120g py130g)
bysort hhid: egen `hinbenef' = sum(`inbenef')
cap drop famtestinc2023_hh famtestinc20203_pc
egen famtestinc2023_hh  = rsum(hy023 `hinbenef') 
gen  famtestinc2023_pc = famtestinc2023_hh/hx040
	
cap drop dt5_fmnc_in
gen double dt5_fmnc_in = `benefmt00' if famtestinc2023_pc<`miny_fam02' & memb_no==1	
replace    dt5_fmnc_in = `benefmt00'*.8 ///
	if inrange(famtestinc2023_pc,`miny_fam02',`miny_fam03') & memb_no==1	

cap drop famtestinc20203_* 
	
tempvar widow widow_in_hhd
gen `widow' = pb190==4 & (child_f>0 | child_m>0)	
bysort hhid: egen `widow_in_hhd' = max(`widow')
replace dt5_fmnc_in = `benefmt00' if lonep_hh>0  & memb_no==1 & `widow_in_hhd' ==1	
rpayi dt5_fmnc_in 
replace dt5_fmnc_ri = 0 if hy053g==0 | hy053g==.
replace dt5_fmnc_ri = 0 if hy052g>0 & hy052g<.
replace dt5_fmnc_in = 0 if dt5_fmnc_ri==0
	
// sumt dt3_fmnc_ri  // 508,252  vs 344,000  /509217/		
sumt dt5_fmnc_ri  // 306,524 vs 344,000 89%  /307027	
sumt dt5_fmnc_in // 137322568 m vs 143  // 96%  /137.446142/	
label var dt5_fmnc_in "Dir.Transfer: Monthly child allowance N-MT (individual)"	
percap dt5_fmnc_in 
	
foreach pc_var of varlist dt5_fmnc_pc  {
		local ae_var = subinstr("`pc_var'","pc","ae",1)
		local pc_lab : variable label `pc_var'
		local ae_lab = subinstr("`pc_lab'","Per capita","Adult equivalent",1)
		cap drop `ae_var'
		gen double  `ae_var' = ((`pc_var'*hsize))/hx050
		label var `ae_var' "`ae_lab'"
}
	
// Estimate poverty and inequality --------------------------------------
	
cap drop y*5_pc 
gen double  yd5_pc = yd_pc - dtr_fmnc_pc + dt5_fmnc_pc + dtx_pitx_pc - dt2_pitx_pc
egen double yc5_pc = rsum(yd3_pc `tot_itx' `tot_sub')
	
tempvar tot_itx tmp_yc tot_sub  tot_itxae tot_subae
egen double `tot_itx'   = rsum(itx_vatx_pc  itx_oild_pc  itx_oili_pc  itx_beve_pc  itx_toba_pc)
egen double `tot_itxae' = rsum(itx_vatx_ae  itx_oild_ae  itx_oili_ae  itx_beve_ae  itx_toba_ae)
replace `tot_itx'   = `tot_itx'*-1
replace `tot_itxae' = `tot_itxae'*-1
		
egen double `tot_sub' = rsum(sub*pc)
egen double `tot_subae' = rsum(sub*ae)

cap drop y*5_ae 		
gen double  yd5_ae = yd_ae - dtr_fmnc_ae + dt5_fmnc_ae + dtx_pitx_ae - dt2_pitx_ae 
egen double yc5_ae = rsum(yd5_ae `tot_itxae' `tot_subae')
	
label var yd5_pc "Disposable income Scen 5 (per capita)"
label var yc5_pc "Consumable Income Scen 5 (per capita)"	
label var yd5_pc "Disposable income Scen 5 (adult equivalent)"
label var yc5_pc "Consumable Income Scen 5 (adult equivalent)"	
	
display "total ****"
apoverty yc5_ae [w=weight], varpl(pline_mod)
	
display "children ***"
apoverty yc5_ae [w=weight] if child_==1, varpl(pline_mod)
local a0=  real(r(head_1))
di "`i'"
qui summ dtr_fmnc_in [w=weight], meanonly
local a=r(sum)
qui summ dt5_fmnc_in [w=weight], meanonly
local b=r(sum)
local a1 = (`b'-`a')/1000000
local b1 = ((`b'-`a')/`a')*100		
	
mat resa2023  = (`a0' , `a1', `b1')		
mat res2023 = (nullmat(res2023) \ resa2023)	

end 


capture program drop tab_01
program define tab_01 // Coverage in 1st quintile (poorest) (%)
	table `1' if memb_no==1 & inlist(decyp,1,2) [w=weight], stat(percent uno) stat(sum uno)
	collect label dim `1' "`2'", modify
	collect title "Coverage in 1st quintile (poorest) (%), households"
	collect style title, font(, bold italic)
	collect notes `"Source: Own calculations based on EU-SILC"'
	collect notes `"Note: Totals in Households"'
	collect style notes, font(, size(7))
	collect save "${tmp}`3'", replace  
end  

cap program drop tab_02  // coverage of benefits per quintile 
program define tab_02 
	syntax varlist, interv(string) sav(string)
	table decyp [w=weight], stat(percent `varlist' ) stat(sum `varlist' ) nformat(%12.1fc)
	collect label dim decyp "Deciles of Per Capita Market Income plus Pensions", modify
	collect title "`interv'"
	collect style title, font(, bold italic)
	collect label dim decyp "Deciles of Per Capita Market Income plus Pensions", modify
	collect notes `"Source: Own calculations based on EU-SILC"'
	collect notes `"Note: Totals in Euros"'
	collect style notes, font(, size(7))
	collect save "${tmp}`sav'", replace  
end 

cap program drop tab_03  // Coverage of population, by decile 
program define tab_03 
	syntax varlist , sav(string)
	table decyp [w=weight] if memb_no==1, stat(mean  `varlist') nformat(%6.4fc)
	collect label dim decyp "Deciles of Per Capita Market Income plus Pensions", modify
	collect title "Coverage (payers as % of total population of each decile)"
	collect style title, font(, bold italic)
	collect label dim decyp "Deciles of Per Capita Market Income plus Pensions", modify
	collect notes `"Source: Own calculations based on EU-SILC"'
	collect notes `"Note: Percentages"'
	collect style notes, font(, size(7))
	collect save "${tmp}`sav'", replace  
end 

cap program drop tab_04 // share of beneficiaries per quintile 	
program define tab_04
	syntax varlist, sav(string) tit(string)
	table decyp [w=weight] if memb_no==1 , stat(percent `varlist') stat(sum `varlist') nformat(%12.1fc)
	collect title "`tit'"
	collect style title, font(, bold italic)
	collect label dim decyp "Deciles of Per Capita Market Income plus Pensions", modify
	collect notes `"Source: Own calculations based on EU-SILC"'
	collect style notes, font(, size(7))
	collect save "${tmp}`sav'", replace  
end 

capture program drop tab_05
program define tab_05  // benefits as a share of income per quintile 	
syntax varlist, matr(string)
tabstat `varlist' [w=weight], by(decyp) stat(sum) save
tabstatmat gmis 
mata: st_matrix("gmis_i",st_matrix("gmis")[,1]:/st_matrix("gmis")[,2]:*100)
mat rownames gmis_i = d1 2 3 4 5 6 7 8 9 10  Total 
mat colnames gmis_i = Incidence	
matlist gmis_i, format(%5.2fc)
mat `matr' = gmis_i
end 

cap program drop tab_07   // coverage of the poor 
program define tab_07
	
	table `1' if `2'==1  & memb_no==1 [w=weight], stat(sum uno) stat(percent uno)
	collect title "`5'"
	collect label dim `1' "`3'", modify
	collect style title, font(, bold italic)
	collect notes `"Source: Own calculations based on EU-SILC"'
	collect notes `"Note: Totals in Households"'
	collect style notes, font(, size(7))
	collect save "${tmp}`4'", replace
end 
	
cap program drop put_1 
program define put_1
	
	putexcel set "${xlchild}", modify sheet("`1'")
	
	local a: var label `2'_pc 
	local b = subinstr("`a'","(Per capita)","",1)
	local b = subinstr("`b'","Dir.Transfer: ","",1)
	
	putexcel A1 = "`b'", bold italic font(Arial, 12, darkblue)
	
	putexcel (C16:C26), overwritefmt nformat(number_sep) 
	putexcel (B34:C45), overwritefmt nformat(#.0) 
	putexcel (D34:E44), overwritefmt nformat(number_sep) 
	putexcel (I17:J27), overwritefmt nformat(percent_d2) 
	
	putexcel (A48:A48), overwritefmt bold italic
	putexcel A48 = "Adequacy of benefits (% income by decile)"
	putexcel B49 = matrix(`3'), names nformat(number_d2)
	putexcel A49 = matrix(`2'), names nformat(number_d2)
	
	putexcel (I17:J27), overwritefmt nformat(percent_d2) 
	
	putexcel (A63:A63), overwritefmt bold italic
putexcel A63 = "Poverty and Gini change (disposable & consumable income)"
	putexcel D64 = "Child Poverty"
	putexcel A65 = matrix(mg_pov`4'), names nformat(number_d2)
	putexcel B67 = matrix(mg_spov`4'), nformat(number_d2) 		
	putexcel B68 = matrix(mg_ineq`4'), nformat(number_d2) 
	
	putexcel D65 = matrix(mgc_pov`4'), names nformat(number_d2) 		
	putexcel E67 = matrix(mgc_spov`4'),nformat(number_d2) 		
	
	putexcel A66 = "Poverty change" A68 = "Inequality change" ///
	A67 = "Change in Poverty Gap" B65= "Disposable" C65 = "Consumable" ///
	D66 = "Child poverty chg." D67 = "Child pov. gap chg."
	
	putexcel (A70:A70), overwritefmt bold italic
	putexcel A70 = "Number of payers: simulation vs admin"
	summ `2'_rh [w=weight] 
	local di1 = r(sum)
	summ `3'_rh [w=weight] 
	local di2 = r(sum)
	local a: di %18.0fc `di1' " vs " %12.0fc `di2' " base vs simulation"
	putexcel A72 = "`a'"
	
	putexcel (A74:A74), overwritefmt bold italic
	
	putexcel A74 = "Fiscal cost (simulation vs admin)"
	putexcel A76 = "`5'"
	putexcel A77 = "`6'"
	putexcel clear 	
end 

cap program drop put_2	
program define put_2 
	collect clear 
	collect use "${tmp}`1'"
	collect export  "${xlchild}", sheet("`2'") cell(`3') modify 
end 
	
cap program drop pov_04i
program define pov_04i
	syntax varlist [if] , matr(string) 
	tabstat `varlist' `if'	[w=weight], save
	tabstatmat pyc 
	mata: a = ((st_matrix("pyc")[1,2]- st_matrix("pyc")[1,1]):*100, (st_matrix("pyc")[1,4]-st_matrix("pyc")[1,3]):*100)
	mata: st_matrix("`matr'",a)
	local b_varlist = subinstr("`varlist'","py","spy",.)
	tabstat `b_varlist'	`if' [w=weight], save
	tabstatmat spyc 
	mata: a = ((st_matrix("spyc")[1,2]- st_matrix("spyc")[1,1]):*100, (st_matrix("spyc")[1,4]-st_matrix("spyc")[1,3]):*100)
	local b_mg = subinstr("`matr'","_p","_sp",1)
	mata: st_matrix("`b_mg'",a)	
	mat drop spyc pyc 
end	

cap program drop inq_04i
program define inq_04i
	syntax varlist [if] , matr(string) welf(string) welf2(string)
	qui ainequal `welf'  [w=weight]
	scalar G1 = real(r(gini_1))
	qui ainequal `welf2'  [w=weight]
	scalar G2 = real(r(gini_1))
	qui ainequal `varlist' [w=weight]
	scalar G3 = real(r(gini_1))
	scalar G4 = real(r(gini_2))	
	mata: a = ((st_numscalar("G1") - st_numscalar("G3")), (st_numscalar("G2")-st_numscalar("G4")))
	mata: st_matrix("`matr'",a)	
end	

/*============================================================
	0: Select Excel file to send results 
==================================================================*/

// ##########################################################################
global xlchild  = "BGR20_sim_Jan12_2023.xlsx"
global xlchild  = "BGR20_sim_Nov07_2023.xlsx"

/*============================================================
	1: Open processed file 
==================================================================*/
cd "${outp}"

use "BGR20WBN_childp_Aug9_2023.dta", clear 

/// simulations 
//------------------------------------------------------------------------
/// 1. pit 
//  conditional allowance 
//------------------------------------------------------------------------

*----------2.1: Gross Income 

tempvar ytpp_in 

gen  double `ytpp_in' = hy040g if memb_no==1  // Income from rental of a property or land

replace `ytpp_in'=0 if  `ytpp_in'==.

misstable summ `ytpp_in'

// replace ytp_in = ytp_in + `ytpp_in'  // I. Income from all source 	
	// gen double ytpi_in = hy090g if memb_no==1 // I.1 Interest, dividends, profit from capital
// Interest is taxed at a different rate than other income sources

*----------2.2: Deductions 

** 1.2.1 labor contract 
tempvar labinc selfinc 
gen `labinc'=1  if py010g>0 & py010g<. & informal_w==0

** 1.2.2 Self employed 
gen `selfinc'=1 if py050g>0 & py050g<. & informal_s==0 //

/*
	 Freelance professions 25%
	 Agricultural activity (processed products) 40-60%
	 Forestry and fishery activity 40%
	 Income from crafts, trade with decorative plants 40%
	 Artistic/performance activities 40%
	 Income from authorship rights (scientific/art products) 40%
*/

global sh_nre  = 0.25  // freelance  
global sh_nre2 = 0.40  // asumming 40% for agriculture 
global sh_nre3 = 0.10  // other - real state nonfin assets 

cap drop nre 
gen double nre = (py050g*max(pl075, pl076))/12*$sh_nre 

/*
	92	"Agricultural, forestry and fishery labourers"                     ///
	61	"Market-oriented skilled agricultural workers"                      ///
	62	"Market-oriented skilled forestry, fishery and hunting workers"     ///
*/

**only agricultural, forestry and fishery 
	**artistic mixed with legal, social. So not included  (keep as gral rate)
**authorship products (same as above)

replace nre = (py050g*max(pl075, pl076))/12*$sh_nre2 if inlist(pl051a,92, 61,62)
replace nre = max(0,nre) + (`ytpp_in')*$sh_nre3
replace nre = 0 if nre ==.

*----------2.2: Tax Base 

tab `labinc' `selfinc', m	
cap drop ytp2_in 
gen double    ytp2_in = ytp_in - cpn_csse_in - con_hlte_in - con_smte_in - con_unme_in ///
if `labinc'==1 & `selfinc'==.
replace ytp2_in = ytp_in - cpn_csss_in - con_hlts_in - con_smts_in - nre ///
if `selfinc'==1 & `labinc'==.
replace ytp2_in = ytp_in - cpn_csss_in - con_hlts_in - con_smts_in - nre - ///
cpn_csse_in - con_hlte_in - con_smte_in - con_unme_in ///
if `selfinc'==1 & `labinc'==1
summ yt*2_in 

*----------Allowances Escenario 1  

** 1.1 Rates 

global r_dis   = 1		// disabled factor 
global a0_chd  = 6000  // allowance per child 
global a_chd   = ($a0_chd/px010)	 //  4500 .. 6000 in 2023		
global max_chd = ($a0_chd*3)/px010  // 13500 .. 18000 in 2023
global dis_chd = (9000)/px010   // 12000 in 2023
global min_sal = 312  // in Euros monthly 

global max_dis = 7920/px010  // still 7920 in 2022

global pit_rate = 0.10
global int_rate = 0.08

global mult_min = 1
global mult_all = $mult_min // # times minimum salary o food basket 


esc_pitbg dt1

replace child_allowance = round(child_allowance, 0.01)
//table disab_t child_t, stat(mean child_allowance)

global r_dis   = 1		// disabled factor 
global a0_chd  = 3000  // allowance per child BGN 
global a_chd   = ($a0_chd/px010)	 //  4500 .. 6000 in 2023	EUROS 	
global max_chd = ($a0_chd*3)/px010  // 13500 .. 18000 in 2023 EUROS  
global dis_chd = ($a0_chd*2)/px010   // 12000 in 2023    EUROS 
global min_sal = pline_mod*.07 // 7% as a share of the poverty line

global max_dis = 7920/px010  // still 7920 in 2022
global mult_min = 2
global mult_all = $mult_min // # times minimum salary o food basket 

esc_pitbg dt2  // options are globals and 'dt2' for the name of dtx 


*************************************************************************

/// 3. monthly child benefit 

**************************************************************************
	** Means-tested child benefit / bchmt00 -S   14.49 BGN  - 7.4
	*** Non-contributory benefit for raising a child under the age of 1 
	*   For those women and their families, who satisfy the legislated 
	*    income-test, we impute the Non-contributory benefit for raising a 
	*    child under the age of 1 equal to the minimum 
	*    between the legislated amount and HY053. The benefit amount is 
*    adjusted for the child’s quarter of birth


mat res = J(10,5,.)
global mult_mchi =  0.7
global miny_fam02 = (400/EXR)*12*$mult_mchi		  // 100%
global miny_fam03 = (500/EXR)*12*$mult_mchi		  // 80%
di $miny_fam02
di $miny_fam03
cap drop totchild 
egen totchild = 	rsum(sage_18 sage_1820)	

mat drop res 
child_adj01  1.4 dtx_pitx 
child_adj01  1.5 dtx_pitx 

sumt dtr_fmnc_in // 138,635,568 m vs 143  // 96%  /137.446142/
sumt dt3_fmnc_in // 150,725,823 m vs 143  // 96%  /137.446142/

mat colnames res = red_min adj_ben pov ben_inc  pct_ben_inc 
mat esc2 = res 
matlist esc2

/*
             |   red_min    adj_ben        pov    ben_inc  pct_ben~c 
-------------+-------------------------------------------------------
          r1 |        .7        1.4   30.03794   2.041866    1.47283 
          r1 |        .7        1.5   29.89278   12.09025   8.720889 

*/	

rename dt3_fmnc_* dt2_fmnc_*
clonevar dt3_pitx_pc = dtx_pitx_pc 	
clonevar dt3_pitx_ae = dtx_pitx_ae 	
clonevar dt4_pitx_pc = dt2_pitx_pc 	 // + alt scenario 2 
clonevar dt4_pitx_ae = dt2_pitx_ae 	 // + alt scenario 2 

mat drop res 
qui {	
	/*
	local inc01 = 5.0
	local goal  = 20.355
	child_adj01  `inc01'   dt4_pitx  // 
	local inc00 = `inc01'
	local inc02 = resa[1,3]
	while `inc02'> `goal'  {
		local inc00 = `inc00'+ 0.01
		child_adj01  `inc00'    dt4_pitx  
		local inc02 = resa[1,3]
	}
	*/
	child_adj01  1.00   dt4_pitx  // no change 
	child_adj01  1.57   dt4_pitx  // 3
	child_adj01  2.2   dt4_pitx  // 4
	child_adj01  2.87   dt4_pitx  // 6	
	child_adj01  5.08    dt4_pitx  // 10
	child_adj01  3.92    dt4_pitx  // 8
}

mat colnames res = red_min adj_ben pov ben_inc  pct_ben_inc 
mat esc3 = res 
matlist esc3, format(%6.2fc)
	

foreach pc_var of varlist dt2_fmnc_pc dt3_fmnc_pc dt?_pitx_pc  {
	local ae_var = subinstr("`pc_var'","pc","ae",1)
	local pc_lab : variable label `pc_var'
	local ae_lab = subinstr("`pc_lab'","Per capita","Adult equivalent",1)
	cap drop `ae_var'
	gen double  `ae_var' = ((`pc_var'*hsize))/hx050
	label var `ae_var' "`ae_lab'"
}

child_adj02

// Estimate poverty and inequality --------------------------------------
	
// Scenario 1 -2
cap drop y*1_pc y*2_pc  
cap drop y*1_ae y*2_ae
drop y?3_pc 
drop y?3_ae 

clonevar dt4_fmnc_pc = dt3_fmnc_pc 
clonevar dt4_fmnc_ae = dt3_fmnc_ae 
clonevar dt5_pitx_ae = dt2_pitx_ae
clonevar dt5_pitx_pc = dt2_pitx_pc

drop dt3_fmnc_*
rename dt2_fmnc_* dt3_fmnc_*

forval i=1(1)2 {   // PITX is the same for scenario 2 and 3 
	clonevar dt`i'_fmnc_pc = dtr_fmnc_pc 
	clonevar dt`i'_fmnc_ae = dtr_fmnc_ae 
}

rename dtr_fmnc_ae odtr_fmnc_ae 
rename dtr_fmnc_pc odtr_fmnc_pc 
	
forval k=1(1)5 {  // 5 scenarios 
	cap drop yn`k'_pc yn`k'_ae
	gen double yn`k'_pc = yn_pc + dtx_pitx_pc  - dt`k'_pitx_pc
	gen double yn`k'_ae = yn_ae + dtx_pitx_ae  - dt`k'_pitx_ae 
	
	cap drop yd`k'_pc yd`k'_ae
	egen double yd`k'_pc = rsum(yn`k'_pc dtr_*_pc dt`k'_fmnc_pc)	
	egen double yd`k'_ae = rsum(yn`k'_ae dtr_*_ae dt`k'_fmnc_ae)	
	
	label var yn`k'_pc "Net Market income Scen `k' (per capita)"
	label var yd`k'_ae "Disposable income Scen `k' (per capita)"
	
	tempvar tot_itx tmp_yc tot_sub  tot_itxae tot_subae
	egen double `tot_itx'   = rsum(itx_vatx_pc  itx_oild_pc  itx_oili_pc  itx_beve_pc  itx_toba_pc)
	egen double `tot_itxae' = rsum(itx_vatx_ae  itx_oild_ae  itx_oili_ae  itx_beve_ae  itx_toba_ae)
	
	replace `tot_itx'   = `tot_itx'*-1
	replace `tot_itxae' = `tot_itxae'*-1
	
	egen double `tot_sub'   = rsum(sub*pc)
	egen double `tot_subae' = rsum(sub*ae)
	
	cap drop yc`k'_pc yc`k'_ae
	egen double yc`k'_pc = rsum(yd`k'_pc `tot_itx' `tot_sub')
	label var yc`k'_pc "Consumable Income Scen `k' (per capita)"
	egen double yc`k'_ae = rsum(yd`k'_ae `tot_itxae' `tot_subae')
	label var yc`k'_ae "Consumable Income Scen `k' (adult equivalent)"		
}
	
rename odtr_* dtr_*

apoverty yc_ae [w=weight], varpl(pline_mod)
/*
----------------------------------------------
        Poverty measures of yc_ae |      yc_ae
----------------------------------+-----------
                Headcount ratio % |     29.115
Extreme Poverty Headcount ratio % |      4.790
----------------------------------------------
*/	

apoverty yc?_ae [w=weight], varpl(pline_mod)

/*
----------------------------------------------------------------------------------------------
Poverty measures of yc1_ae yc2_ae |
yc3_ae yc4_ae yc5_ae              |     yc1_ae      yc2_ae      yc3_ae      yc4_ae      yc5_ae
----------------------------------+-----------------------------------------------------------
                Headcount ratio % |     28.039      28.039      28.967      25.959      27.931
Extreme Poverty Headcount ratio % |      4.681       4.681       4.556       2.992       4.519
----------------------------------------------------------------------------------------------
*/

apoverty yc_ae [w=weight] if child_==1, varpl(pline_mod)

/*
----------------------------------------------
        Poverty measures of yc_ae |      yc_ae
----------------------------------+-----------
                Headcount ratio % |     30.355
Extreme Poverty Headcount ratio % |      8.731
----------------------------------------------

*/

apoverty yc?_ae [w=weight] if child_==1, varpl(pline_mod)

/*
----------------------------------------------------------------------------------------------
Poverty measures of yc1_ae yc2_ae |
yc3_ae yc4_ae yc5_ae              |     yc1_ae      yc2_ae      yc3_ae      yc4_ae      yc5_ae
----------------------------------+-----------------------------------------------------------
                Headcount ratio % |     27.681      27.681      29.893      22.312      27.473
Extreme Poverty Headcount ratio % |      8.298       8.298       8.068       3.966       7.920
----------------------------------------------------------------------------------------------
*/

cap drop decyp 
// Households coverage in 1st quintile MPP 
quantiles yp_pc [w=weight], n(10) gen(decyp) k(hhid)

// Recipientes 
forval i=1(1)5 {  // 5 scenarios 
		gen dt`i'_pitx_rh = (dt`i'_pitx_pc>0 & memb_no==1)
		gen dt`i'_fmnc_rh = (dt`i'_fmnc_pc>0 & memb_no==1)
}

local i = 1

//foreach var of local escn {
// cap drop gmi_yc_ae gmi_yd_ae gmi_yc_pc gmi_yd_pc

local tabxl = "`var'"
cap drop uno 
gen uno = 1 


/*====================================================================================================
	2: Tables 
==================================================================*/

*----------2.1: Coverage in 1st quintile (poorest) (%)

bysort hhid: egen dtx_pitx_rh = max(dtx_pitx_ri)
bysort hhid: egen dtr_fmnc_rh = max(dtr_fmnc_ri)

tab_01 dtx_pitx_rh "=1 if pays PIT" uno_1_t0
tab_01 dtr_fmnc_rh "=1 if receives the transfer" uno_1_d0

forval i=1(1)5 {
	tab_01 dt`i'_pitx_rh "=1 if pays PIT" uno_1_t`i'
	tab_01 dt`i'_fmnc_rh "=1 if receives the transfer" uno_1_d`i'


*----------2.2: Benefits incidence (% benefits accruing to each quintile)
// coverage of benefits per quintile 

	tab_02 dtx_pitx_pc dt`i'_pitx_pc, interv("Incidence (% tax accruing to each decile)")  sav(uno_2_t`i')
	tab_02 dtr_fmnc_pc dt`i'_fmnc_pc, interv("Benefits incidence (% benefits accruing to each decile)")  sav(uno_2_d`i')


** 2.3 Coverage of population, by decile 

	tab_03  dtx_pitx_rh dt`i'_pitx_rh, sav(uno_3_t`i')	
	tab_03  dtr_fmnc_rh dt`i'_fmnc_rh, sav(uno_3_d`i')

*----------2.4: Beneficiary incidence (% beneficiary accruing to each quintile)	
// share of beneficiaries per quintile 	

	tab_04 dtx_pitx_rh dt`i'_pitx_rh, sav(uno_4_t`i') tit("Incidence (% payers accruing to each decile), households")	
	tab_04 dtr_fmnc_rh dt`i'_fmnc_rh, sav(uno_4_d`i') tit("Incidence (% beneficiaries accruing to each decile), households")

*----------2.5: Adequacy of benefits (% income by quintile)
// benefits as a share of income per quintile 	

	tab_05 dt`i'_pitx_pc yp_pc, matr(dt`i'_pitx)	
	tab_05 dt`i'_fmnc_pc yp_pc, matr(dt`i'_fmnc)	
}

tab_05 dtx_pitx_pc yp_pc, matr(dtx_pitx)
tab_05 dtr_fmnc_pc yp_pc, matr(dtr_fmnc)

*----------2.6: Marginal Contributions to Poverty and Gini
// Marg contributions to Poverty (PA) 
//	- Disposable Income	
//  - Consumable Income 

foreach var2 of varlist yd_ae  yd?_ae yc_ae yc?_ae yp_ae {
	pov_1 `var2' pline_mod p`var2'
}	
	
forval i=1(1)5 {  // 5 scenarios 
	// pov_04i  varlist destination matrix 
	pov_04i pyd_ae pyd`i'_ae pyc_ae pyc`i'_ae, matr("mg_pov`i'")
	pov_04i pyd_ae pyd`i'_ae pyc_ae pyc`i'_ae if child_==1, matr("mgc_pov`i'")	
	inq_04i   yd`i'_pc   yc`i'_pc , matr("mg_inq`i'") welf(yd_pc) welf2(yc_pc)	
}	

	
// Marg contributions to inequality 	
	//	- Consumable Income 
//	- Disposable Income		
	
	forval i=1(1)5 {  // 5 scenarios 
		mat mg_ineq`i' = J(1,2,.)
		covconc yd_pc   [w=weight]
		local ayd = r(gini)
		covconc yd1_pc   [w=weight]
		local gyd = r(gini)
		mat mg_ineq`i'[1,1] = `gyd'-`ayd'
		
		covconc yc_pc   [w=weight]
		local ayc = r(gini)
		covconc yc1_pc   [w=weight]
		local gyc = r(gini)
		mat mg_ineq`i'[1,2] = `gyc'-`ayc'
		
		mat rownames mg_ineq`i' = MarginalContribInequality
		mat colnames mg_ineq`i' = disp. cons.
		
		matlist mg_ineq`i'
	}
	
	*----------2.7: Coverage of the poor / disp income 
	
	tab_07  dtx_pitx_rh pyp_ae "=1 if pays the tax" uno_7_t0 "Coverage of poor (pre-fiscal income MYPP) (%), households"
	tab_07  dtx_pitx_rh pyd_ae "=1 if pays the tax" uno_7_td0 "Coverage of poor (disposable income) (%), households"
	tab_07  dtr_fmnc_rh pyp_ae "=1 if receives the transfer" uno_7_d0 "Coverage of poor (pre-fiscal income MYPP) (%), households"
	tab_07  dtr_fmnc_rh pyd_ae "=1 if receives the transfer" uno_7_dd0 "Coverage of poor (disposable income) (%), households"
	
	forval i=1(1)5 {		// 5 scenarios 
		tab_07  dt`i'_pitx_rh pyp_ae "=1 if pays the tax" uno_7_t`i' "Coverage of poor (pre-fiscal income MYPP) (%), househ	olds"			
		tab_07  dt`i'_fmnc_rh pyp_ae "=1 if receives the transfer" uno_7_d`i' "Coverage of poor (pre-fiscal income MYPP) (%), households"
		tab_07  dt`i'_pitx_rh pyd_ae "=1 if pays the tax" uno_7_td`i' "Coverage of poor (pre-fiscal income MYPP) (%), househ	olds"			
		tab_07  dt`i'_fmnc_rh pyd_ae "=1 if receives the transfer" uno_7_dd`i' "Coverage of poor (pre-fiscal income MYPP) (%), households"
	}
	
	
	*----------2.6: Number of beneficiaries: admin vs simulation
	// Households 
	
	//summ `var'_rh [w=weight] 
	
	//di %18.0fc r(sum) as text " vs 27,000 admin figures. Ratio:" as result %6.4fc r(sum)/27000
	
	
	*----------2.8: Fiscal cost (admin vs simulation)
	// Euros - BGN 
	scalar EXR = px010[1]
	
	// Scenario 1: new PIT 2023
	summ dtx_pitx_pc [w=weight], meanonly 
	local tot1_1 = r(sum)/1000000
	summ dt1_pitx_pc [w=weight], meanonly 
	local tot2_1 = r(sum)/1000000
	local dif01 = `tot2_1' -`tot1_1'
	local pdif01 = (`dif01'/`tot1_1')*100
	display as result %18.0fc `tot1_1' as text " collection baseline" _newline ///
	as result %18.0fc `tot2_1' as text " collection  simulation 1"  _newline ///
	as result %18.0fc `dif01' as text " difference"  _newline ///
	as result %18.0fc ((`dif01') / `tot1_1')*100 as text "%" 
		
	local a1_1: display %18.0fc `tot1_1' " EUR collection baseline ---" ///
		%18.0fc `tot1_2' " EUR collection  simulation 1"
	local a2_1:  display "difference:..."  %18.0fc `dif01' " EUR millions --" %6.4fc `pdif01' " % " 	
	
	display "`a1_1'"
	display "`a2_1'"
	
	// Scenario 2: new PIT 2023 vs simulation PIT 2023
	
	summ dt1_pitx_pc [w=weight], meanonly 
	local tot1_2 = r(sum)/1000000
	summ dt1_pitx_pc [w=weight], meanonly 
	local tot2_2 = r(sum)/1000000
	local dif02 = `tot2_2' -`tot1_2'
	display as result %18.0fc `tot1_2' as text " collection baseline" _newline ///
	as result %18.0fc `tot2_2' as text " collection  simulation 1"  _newline ///
	as result %18.0fc `dif02' as text " difference"  _newline ///
	as result %18.0fc ((`dif02') / `tot2_1')*100 as text "%" 
		
	local a1_2: display %18.0fc `tot2_1' " EUR collection 2023 ---" ///
	%18.0fc `tot2_2' " EUR collection  simulation 1"
	local a2_2:  display "difference:"  %18.0fc `dif02' " EUR millions --" ///
	%18.0fc ((`dif02') / `tot1_2')*100 "%" 
	display "`a1_2'"
	display "`a2_2'"
	
	
	// Scenenario 3
	
	summ dtr_fmnc_pc [w=weight], meanonly 
	local tot1_3 = r(sum)/1000000
	summ dt2_fmnc_pc [w=weight], meanonly 
	local tot2_3 = r(sum)/1000000
	local dif03 = `tot2_3' - `tot1_3'
	display as result %18.0fc `tot1_3' as text " expenditure baseline" _newline ///
	as result %18.0fc `tot2_3' as text " expenditure  simulation 2"  _newline ///
	as result %18.0fc `dif03' as text " difference"  _newline ///
	as result %18.0fc ((`dif03') / `tot1_3')*100 as text "%" 
	
	local a1_3: display %18.0fc `tot1_3' " EUR expenditure baseline ---" ///
	%18.0fc `tot2_3' " EUR expenditure  simulation CHILD ALLOWANCE"
	local a2_3:  display "difference:"  %18.0fc `dif02' " EUR millions --" ///
	%18.0fc ((`dif03') / `tot1_3')*100 "%" 
	display "`a1_3'"
	display "`a2_3'"
	
	// Scenario 4
	
	summ dtr_fmnc_pc [w=weight], meanonly 
	local tot1_4 = r(sum)/1000000
	summ dt3_fmnc_pc [w=weight], meanonly 
	local tot2_4 = r(sum)/1000000
	local dif04 = `tot2_4' - `tot1_4'
	display as result %18.0fc `tot1_4' as text " expenditure baseline" _newline ///
	as result %18.0fc `tot2_4' as text " expenditure  simulation 2"  _newline ///
	as result %18.0fc `dif04' as text " difference"  _newline ///
	as result %18.0fc ((`dif04') / `tot1_4')*100 as text "%" 
	
	local a1_4: display %18.0fc `tot1_4' " EUR expenditure baseline ---" ///
	%18.0fc `tot2_4' " EUR expenditure  simulation CHILD ALLOWANCE aspirational"
	local a2_4:  display "difference:"  %18.0fc `dif04' " EUR millions --" ///
	%18.0fc ((`dif04') / `tot1_4')*100 "%" 
	display "`a1_4'"
	display "`a2_4'"
	
	// Scenario 5
	
	summ dtr_fmnc_pc [w=weight], meanonly 
	local tot1_5 = r(sum)/1000000
	summ dt5_fmnc_pc [w=weight], meanonly 
	local tot2_5 = r(sum)/1000000
	local dif05 = `tot2_5' - `tot1_5'
	display as result %18.0fc `tot1_5' as text " expenditure baseline" _newline ///
	as result %18.0fc `tot2_5' as text " expenditure  simulation 2"  _newline ///
	as result %18.0fc `dif05' as text " difference"  _newline ///
	as result %18.0fc ((`dif05') / `tot1_5')*100 as text "%" 
	
	local a1_4: display %18.0fc `tot1_5' " EUR expenditure baseline ---" ///
	%18.0fc `tot2_5' " EUR expenditure  simulation CHILD ALLOWANCE 2023"
	local a2_4:  display "difference:"  %18.0fc `dif03' " EUR millions --" ///
	%18.0fc ((`dif05') / `tot1_5')*100 "%" 
	display "`a1_5'"
	display "`a2_5'"
	
	// fiscal cost  two policies -------------------------------------------
	
	
	// 2.8 export 
	
// Scenario 1 
	// sheet, orig, sim, no_scenario title1 title2 
	
	local scenarios pit pit_2 child child_asp child_2023
	tokenize `scenarios'
	
	put_1 "`1'"  dtx_pitx dt1_pitx 1 "`a1_1'" "`a2_1'" 	
	put_1 "`2'"  dtx_pitx dt2_pitx 2 "`a1_2'" "`a2_2'" 	
	put_1 "`3'"  dtr_fmnc dt3_fmnc 3 "`a1_3'" "`a2_3'" 	
	put_1 "`4'"  dtr_fmnc dt4_fmnc 4 "`a1_4'" "`a2_4'" 	
	put_1 "`5'"  dtr_fmnc dt5_fmnc 5 "`a1_5'" "`a2_5'" 	
	
	local i=1
	foreach sim in "t1" "t2" "d3" "d4" "d5" {
		local sim0  = substr("`sim'",1,1)+"0"
		local simd0 = substr("`sim'",1,1)+"d0"
		local simd  = substr("`sim'",1,1)+"d"+substr("`sim'",2,1)			  
		
		put_2 "uno_1_`sim0'" "``i''"   " A3"  // json tab cell 
		put_2 "uno_1_`sim'" "``i''"     "A3"  // json tab cell 		
		put_2 "uno_2_`sim'" "``i''"     "A13"
		put_2 "uno_3_`sim'" "``i''"     "H14"
		put_2 "uno_4_`sim'" "``i''"     "A31"
		put_2 "uno_7_`sim0'" "``i''"	 "H31"
		put_2 "uno_7_`sim'"  "``i''"	 "L31"
		put_2 "uno_7_`simd0'"   "``i''" "H48"
		di "`simd'"
		put_2 "uno_7_`simd'"    "``i''"  "L48"	
		
		local ++i
	}
	
	apoverty yc_ae if child_==1 [w=weight], varpl(pline_mod)
	local pov0=real(r(head_1))
	local c0 = colsof(res)	
	mata: a=st_local("pov0")	
	mata: st_matrix("res2", (strtoreal(a):-st_matrix("res")[.,3],st_matrix("res")[.,5]))
	
	svmat res2, name(povres)
	format povres2 %3.0fc
	twoway (bar povres2 povres1 if povres1>3.5) (scatter povres2 povres1 if povres1>3.5, mlabel(povres2) mlabposition(-2)) ///
	if povres1 >0 & povres1 !=. , ytitle(`"Child allowance increase (%)"') xtitle(`"Poverty reduction (p.p.)"') ///
	legend(off) graphregion(fcolor(white))
	
	graph export "${outp}pov_childa.png", replace
	
	mata: b = xl()
	mata: b.load_book("${xlchild}")
	mata: rows = (1,27)
	mata: cols = (1,10)
	mata: b.delete_sheet("child_asp_pov")
	mata: b.close_book()
	
	putexcel set "${xlchild}", modify sheet("child_asp_pov")
	putexcel B2 = image("${outp}pov_childa.png")
	putexcel clear 	
	cap putexcel close 
	exit 
	
	put_2 "uno_1_t0" "pit" "A3"  // json tab cell 
	put_2 "uno_1_t1" "pit" "F3"	
	
	put_2 "uno_1_t0" "pit"   "A3"  // json tab cell 
	put_2 "uno_1_t2" "pit_2" "F3"	
	
	put_2 "uno_1_d0" "child" "A3"  // json tab cell 
	put_2 "uno_1_d3" "child" "F3"
	
	put_2 "uno_1_d0" "child_asp" "A3"
	put_2 "uno_1_d4" "child_asp" "F3"	
	
	put_2 "uno_1_d0" "child_2023" "A3"
	put_2 "uno_1_d5" "child_2023" "F3"	

	// 2.2 Benefits incidence 
	
	put_2 "uno_2_t1" "pit" "A13"
	put_2 "uno_2_t2" "pit_2" "A13"
	put_2 "uno_2_d3" "child" "A13"
	put_2 "uno_2_d4" "child_asp" "A13"
	put_2 "uno_2_d5" "child_2023" "A13"
	
	// 2.3 Coverage 
	
	put_2 "uno_3_t1" "pit" 		 "H14"
	put_2 "uno_3_d2" "child"     "H14"
	put_2 "uno_3_d3" "child_asp" "H14"	
	put_2 "uno_3_d5" "child_2023" "H14"	
	
	// 2.4 Beneficiary incidence 
	
	put_2 "uno_4_t1" "pit" 		 "A31"
	put_2 "uno_4_d2" "child"     "A31"
	put_2 "uno_4_d3" "child_asp" "A31"
	put_2 "uno_4_d5" "child_2023" "A31"
	
	// 2.5 Adequacy of benefits 
	
	put_2 "uno_7_t0" "pit" 		"H31"
	put_2 "uno_7_t1" "pit" 		"L31"
	put_2 "uno_7_td0" "pit" 		"H48"
	put_2 "uno_7_td1" "pit" 		"L48"	
	
	put_2 "uno_7_d0" "child" 		"H31"
	put_2 "uno_7_d2" "child" 		"L31"
	put_2 "uno_7_dd0" "child" 		"H48"
	put_2 "uno_7_dd2" "child" 		"L48"
	
	put_2 "uno_7_d0" "child" 		"H31"
	put_2 "uno_7_d3" "child" 		"L31"
	put_2 "uno_7_dd0" "child" 		"H48"
	put_2 "uno_7_dd3" "child" 		"L48"	
	
	
	cap putexcel close 
	
	
	