/*==================================================
	project:       CEQ Bulgaria 2020
	Author:        Cabrera 
	E-email:       maynor.cabrera@ceqinstitute.org
	url:           
	Dependencies:  World Bank 
	Input files 
	- BGR20_mkt_inc.dta
	
	Output files:
	- BGR20_mpp_inc.dta 
	----------------------------------------------------
	Creation Date:       10 Dec 2021
	Modification Date:   29 Apr 2023
	Do-file version:    2.2
	
	References:          
	- Euromod Bulgaria Report 
	Tosheva, E., Tasseva, I., Dimitrova, D. Draganov, D. & V. Boshnakov (2022),  
	“Euromod Country Report Bulgaria BULGARIA (BG) 2019-2022” 
	
================================================== */

/*==================================================
	1: Pensions estimation 
==================================================*/

*----------1.1: Check if market Income is opened 
local cfi = substr(c(filename),ustrlen("${tmp}")+1,11)
di "`cfi'"
if "`cfi'" != "BGR20_mkt_inc" | c(changed)==1 {
	use "${tmp}BGR20_mkt_inc.dta", clear
}

*----------1.2: Creating and labeling variables 

clonevar age=rx020
gen int gender=(rb090==2)
label define gender 1 "Female" 0 "Male"
label values gender gender
label var gender  "Gender"

*----------1.3: Contributory pensions 
summ py102g [w=weight], meanonly
di %18.0fc r(sum) //  5,113,786,787


summ py102g [w=weight] if (age>53 & gender==1) | (age>56 & gender==0)
di %18.0fc r(sum) // 4,916,904,568


// early retirement with at least 	// info for 2020	// Retirement age 
	// Women 61.5   Men 64.25 	
	// 38.8 years of working for men == 56.8
// 35.8 for women == 18+36 = 54 years 

gen double pen_csss_in = py102g if (age>53 & gender==1) | (age>56 & gender==0)
recode pen_csss_in (.=0)

// pensions to age lower than specified go to other transfers 
gen double dtr_othr_in = min(py102g,0) if pen_csss_in==0

label var pen_csss_in "Contributory old-age pensions (individual)"
label var dtr_othr_in "Direct transfers: other (individual)"

cap drop _*
percap pen_csss_in 

*----------1.4: Check totals 

// total benefits pensions 

local bpen1=  4718.31
summ  pen_csss_pc [w=round(weight)], meanonly
di %18.0fc r(sum)/1000000           // 4,917
di %6.4fc (r(sum)/1000000)/`bpen1'  //1.0421

/*
	bg stat 
	
	4,718.31 	
	- 
	** survey   4916.9  [4916.9 / 4718.31 = 1.042]
	
	Variable |             Sum
	-------------+----------------
	pen_csss_pc |   4,916,904,568
	------------------------------	
*/	

rpayi pen_csss_in 

// number of beneficiaries 

local bpen2= 1793000
summ  pen_csss_ri [w=round(weight)], meanonly
di %12.0fc r(sum)
// 1740334
di %6.4fc r(sum)/`bpen2'
// 0.9706

/* 
	(frequency weights assumed)
	
	Recipients |
	of |
	Contributor |
	y old-age |
	pensions  |      Freq.     Percent        Cum.
	------------+-----------------------------------
	0 |  5,182,599       74.86       74.86
	1 |  1,740,334       25.14      100.00
	------------+-----------------------------------
	Total |  6,922,933      100.00
	
	EUROMOD -  1793
	SILC    -  1740  - 97%
	
*/	

/*==================================================
	2: Market Income plus pensions PGT 
==================================================*/

gen double ye_pc= ym_pc + (pen_csss_pc)
label var ye_pc "Market Income plus pensions PGT (per capita)"

tempvar ye_pc_lcu ye_ae_lcu 
gen `ye_pc_lcu' = (ye_pc*px010)
gen double `ye_ae_lcu'     = (`ye_pc_lcu'*hsize)/hx050

ainequal ye_pc ym_pc [w=round(weight)] 
povcc `ye_pc_lcu' [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
povcc `ye_pc_lcu' [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
povcc `ye_pc_lcu' [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62)
povcc `ye_ae_lcu' [fw=round(weight)], pline(PNATM) nn("ppp 5.5")  ppof(3.62)


/*
	---------------------------------------------------
	Inequality measures 		|      ye_pc       ym_pc
	---------------------------+-----------------------
	Gini coefficient 		|    0.42801     0.49445
	Theil index (GE(a), a = 1) 	|    0.35352     0.46004
	---------------------------------------------------
	
	ppp 1.9:  1.64, official:  0.87
	ppp 3.2:  3.06, official:  2.16
	ppp 5.5:  5.85, official:  6.90
	
	. povcc `ye_pc_lcu' [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
ppp 1.9:  2.95, official:  0.25

. povcc `ye_pc_lcu' [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
ppp 3.2:  4.90, official:  1.36

. povcc `ye_pc_lcu' [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62)
ppp 5.5:  7.19, official:  3.62

. povcc `ye_ae_lcu' [fw=round(weight)], pline(PNATM) nn("ppp 5.5")  ppof(3.62)
ppp 5.5: 22.48, official:  3.62


	
	*/
**"

/*==================================================
	3: Social security contributions to pensions	
==================================================*/


	*----------3.1:  Labor market variables & taxable income for contributions 
	
/*	
	pl040:
	1 self-employed with employees
	2 self-employed without employees
	3 employee
	4 family worker
	
	pl031:
	1 Employee working full-time
	2 Employee working part-time
	3 Self-employed working full-time (including family worker)
	4 Self-employed working part-time (including family worker)
	5 Unemployed
	6 Pupil, student, further training, unpaid work experience
	7 In retirement or in early retirement or has given up business
	8 Permanently disabled or/and unfit to work
	9 In compulsory military community or service
	10 Fulfilling domestic tasks and care responsibilities
	11 Other inactive person
*/


/*
	VALUES AND FORMAT
	1 Self-employed with employees
	2 Self-employed without employees
	3 Employee
	4 Family worker (unpaid)
*/


recode pl040a (1/2=3) (3=1) (4=5) /*(22=3)*/, gen(employ_status)

label define employ_status 1 "Employees" 2 "Employers" 3 "Self-employed" ///
4 "Members of producers' cooperatives" 5 "Contributing to family work" ///
6 "Workers not classifiable by status" .z "Unemployed" ///
.y "Domestic workers" .x "Inactive" .w "Age below 15" 

label val employ_status employ_status

/*
	PL032: SELF-DEFINED CURRENT ECONOMIC STATUS	
	
	1 Employed
	2 Unemployed
	3 Retired
	4 Unable to work due to long-standing health problems
	5 Student, pupil
	6 Fulfilling domestic tasks
	7 Compulsory military or civilian service
	8 Other
*/	

/*
	px050 
	1 =
	2 = SAL
	3 = NSAL
	4 = other employed (when time of SAL and NSAL is > ½ of total time calendar)
	5 = unemployed
	6 = retired
	7 = inactive
	8 = other inactive (when time of unemployed, retirement and inactivity is > ½ of total time calendar)	
*/

replace employ_status=.z if (pl032==2 | px050 == 5) & (py010g==0 | py010g==.)
replace employ_status=.x if inlist(pl032,4,5,6,8) & (py010g==0 | py010g==.) // military is active
replace employ_status=.x if inlist(px050,6,7,8) & (py010g==0 | py010g==.)


label var age  "Age of the household member"
summ age 

/*
    Variable |        Obs        Mean    Std. dev.       Min        Max
	-------------+---------------------------------------------------------
	age |     17,249    49.22082    22.53491          0         81
*/

tab gender [w=round(weight)]

/*
	Gender |      Freq.     Percent        Cum.
	------------+-----------------------------------
	Male |  3,875,711       55.98       55.98
	Female |  3,047,222       44.02      100.00
	------------+-----------------------------------
	Total |  6,922,933      100.00
*/

label var pl073 "Number of months spent in full-time work as employee"
label var pl074 "Number of months spent in part-time work as employee"
label var pl075 "Number of months spent in full-time work as self-employed [including family worker]"
label var pl076 "Number of months spent in part-time work as self-employed [including family worker]"

// floor and ceilling for SIC 

scalar PEN_CEILLING = 3000/EXR	
scalar PEN_FLOOR    =  610/EXR  // it was 560 in 2018
scalar PEN_FLOOR_S = 560/EXR

// informaliy for wage earners
gen 	int informal_w = (py010g<PEN_FLOOR) 	
replace informal_w =.  if employ_status>=.
replace informal_w = 1 if py030g==0 | py030g>=.		
replace informal_w = 1 if hy140g==0 | hy140g>=.	& informal_w==0	
// replace informal_w = 0 if informal_w ==1  //  paying SSC

// taxable income wages 
gen double ytcw_in = py010g if employ_status==1 & informal_w==0  // excluding family workers 			
replace ytcw_in = PEN_CEILLING*pl073 if (py010g>PEN_CEILLING*pl073) & ///
	employ_status==1 & informal_w==0
replace ytcw_in = 0 if (ytcw_in==. | informal_w==1)

// government  - inlist(pl051a,0,1,2,4,10,11)  & pl111a==10
gen double ytcw2_in = ytcw_in 
// replace ytcw_in = 0 if   & employ_status==1
// replace ytcw_in = 0 if inlist(pl051a,0,1,2,4,10,11) & employ_status==1

// informality for self-employed
gen int informal_s = (py050g<PEN_FLOOR)
replace informal_s =. if employ_status>=.
replace informal_s = 1 if py030g==0 | py030g==.
replace informal_s = 0 if hy140g>0 & hy140g<. & informal_s ==1 & py050g>0 & py050g<.
replace informal_s = 0 if py030g>0 & py030g<. & informal_s ==1 & py050g>0 & py050g<.

// taxable income (self-employed)
gen double ytcs_in = py050g  if  informal_s==0 & employ_status==3
replace ytcs_in =  PEN_FLOOR_S*pl075 if (py050g<(PEN_FLOOR_S*pl075)) & ///
 informal_s==0 & employ_status==3
replace ytcs_in = PEN_CEILLING*pl075 if (py050g>(PEN_CEILLING*pl075)) & ///
informal_s==0 & employ_status==3	
replace ytcs_in = 0 if (ytcs_in==. | informal_s==1)

*----------3.2:  Employee Social contributions 

/*
	From Euromod 
	----------------------------------------------------------------------------------
	Employees at Labour contract 
	1. Pension Fund
	1.a. PF rate for persons born before 1960								8.78%
	1.b. PF rate for persons born after 1959* 								6.58% 
	2. Supplementary Mandatory Pension Insurance Fund (Universal Pension Funds)
	2.a. SMPIF rate for persons born before 1960							 N/A
	2.b. SMPIF rate for persons born after 1959* 							2.2%
	3. General Sickness and Maternity Fund								1.4%
	4. Unemployment Fund												0.4%
	5. Work Injury and Occupational Disease Fund    						N/A
	Total														10.58%	
	Monthly 
	Upper threshold for the contributory income (BGN) 			3 000 (EUR 1533.90)
	Minimum wage (BGN)									  600
*/

global e_pfb = 0.0878
global e_pfa = 0.0658 + 0.022	
global e_smt = 0.014	
global e_unm = 0.004	
global e_hlt = 0.032   // 40% employee 

gen double cpn_csse_in    =ytcw_in*($e_pfb) if pb140 < 1960 // pension  worker/employee  
replace cpn_csse_in=ytcw_in*($e_pfa) if pb140 >= 1959		
gen double con_smte_in    =ytcw_in*($e_smt) // sickness & maternity fund   		
gen double con_unme_in    =ytcw_in*($e_unm) //  unemployment fund 
gen double con_hlte_in	   =ytcw_in*($e_hlt) // health fund 

** conditions health insurance 
	/*
	-	The State pays the health insurance contributions for the pensioners, unemployed 
	receiving unemployment benefits, individuals under 18 years, students in the 
	tertiary education and civil servants;
	- People above 18 years of age, who simultaneously: 
	(1) are not enrolled in education; 
	(2) do not perform economic activity; 
	(3) are not pensioners; 
	(4) 	do not receive cash benefit for temporary reduced working capacity, pregnancy 
	and childbirth or adoption of a child; 
	(5) do not receive unemployment benefit; 
	(6) do not receive monthly social assistance or heating allowance, 
	are obliged to pay health insurance contributions at their own expense.	
	
	The monthly payment for people who are not insured and have to pay health 
	insurance contributions at their expense was BGN 22.40 in 2019	
*/


// check totals 
mat pen2 = (1389.83 , 214.44 , 61.17 , 630.47)
tabstat cpn_csse_in con_smte_in con_unme_in con_hlte_in [w=round(weight)], ///
stat(sum) col(stat) format(%18.0fc) save
tabstatmat pen1
mata: a=(st_matrix("pen1"):/1000000):/st_matrix("pen2")
mata: b=(a \ st_matrix("pen1"):/1000000 \ st_matrix("pen2"))
mata: st_matrix( "pen3", b)	
mat colnames pen3 = pension SicKMatF unem health 
matlist pen3, format(%12.2fc)

/*
             |      pension      SicKMatF          unem        health 
-------------+--------------------------------------------------------
          r1 |         1.04          1.08          1.08          0.84 
          r2 |     1,447.72        230.84         65.96        527.64 
          r3 |     1,389.83        214.44         61.17        630.47 



	
*/

*----------3.3:  Employers social contributions 

/*
	----------------------------------------------------------------------------------
	Employer social contributions (tscerpi_s, tscersi_s, tscerui_s, tscerac_s)
	3rd category of labour
	1. Pension Fund
	1.a. PF rate for persons born before 1960			11.02%
	1.b. PF rate for persons born after 1959* 			8.22% 
	2. Supplementary Mandatory Pension Insurance Fund (Universal Pension Fund)
	2.a. SMPIF rate for persons born before 1960			N/A
	2.b. SMPIF rate for persons born after 1959* 			2.8%
	3. General Sickness and Maternity Fund					2.1%
	4. Unemployment Fund									0.6%
	5. Work Injury and Occupational Disease Fund (avg)		0.7%  [0.4 to 1.1%]
	Total												14.42%
	
	----------------------------------------------------------------------------------
	Table 2.5.2b SIC rates for employers-insurers on Labour Contract – 1st and 2nd category of labour
	2ND 					1ST
	1. Pension Fund
	1.a. PF rate for persons born before 1960			14.02%				14.02%
	1.b. PF rate for persons born after 1959* 			11.22% 				11.22%
	2. Supplementary Mandatory Pension Insurance Fund (Universal Pension Fund)
	2.a. SMPIF rate for persons born before 1960			N/A
	PPF (Professional Pension Fund)**					7.0%					12.0%
	UPF (Universal Pension Fund)**						N/A
	2.b. SMPIF rate for persons born after 1959 			
	PPF (Professional Pension Fund)**					7.0%					12.0%
	UPF (Universal Pension Fund)*						2.8%					2.8%
	3. General Sickness and Maternity Fund					2.1%					2.1%
	4. Unemployment Fund									0.6%					0.6%
	5. Work Injury and Occupational Disease Fund (avg)		0.7%  [0.4 to 1.1%]	0.7%
	Total												24.42%				29.42%
*/

global p_pfb = 0.1102
global p_pfa = 0.0822 + 0.028	
global p_smt = 0.021	
global p_unm = 0.006
global p_wki = 0.007	
global p_hlt = 0.048  // 60% of total 

gen double cpn_cssp_in    =ytcw2_in*($p_pfb) if pb140 <1960 // pension  worker/employee  
replace cpn_cssp_in=ytcw2_in*($p_pfa) if pb140 >= 1959		
gen double con_smtp_in    =ytcw2_in*($p_smt) // sickness & maternity fund   		
gen double con_unmp_in    =ytcw2_in*($p_unm) //  unemployment fund 
gen double con_wkip_in    =ytcw2_in*($p_wki) //  Work Injury and Occupational Disease Fund
gen double con_hltp_in	   =ytcw2_in*($p_hlt) // health fund 

// check totals 
mat emp2 =( 2274.69 ,  375.59 ,  120.47 ,  107.29 ,  939.25 )	
tabstat cpn_cssp_in con_smtp_in con_wkip_in con_unmp_in con_hltp_in [w=round(weight)], ///
stat(sum) col(stat) format(%18.0fc) save			
tabstatmat emp1
mata: a=(st_matrix("emp1"):/1000000):/st_matrix("emp2")
mata: b=(a \ st_matrix("emp1"):/1000000 \ st_matrix("emp2"))
mata: st_matrix( "emp3", b)	
mat colnames emp3 = pension SicKMatF WkInj unem health 
matlist emp3, format(%12.2fc)

/* 
             |      pension      SicKMatF         WkInj          unem        health 
-------------+----------------------------------------------------------------------
          r1 |         0.90          1.04          1.08          1.04          0.95 
          r2 |     2,056.65        391.92        130.64        111.98        895.82 
          r3 |     2,274.69        375.59        120.47        107.29        939.25 

*/

*----------3.4:  Self employed  social contributions 
/*
	----------------------------------------------------------------------------------
	2.5.3 Social insurance contribution rates for self-employed
	
	1. Pension Fund
	1.a. PF rate for persons born before 1960						19.8%				
	1.b. PF rate for persons born after 1959* 						14.8% 				
	2. Supplementary Mandatory Pension Insurance Fund 			
	(Universal Pension Fund)											5.0%	
	3. General Sickness and Maternity Fund								3.5%					
	(insurance on a voluntary basis)
	Contributory income for self-employed
	Lower threshold (BGN per month)								560
	Upper threshold (BGN per month)								3 000
	Contributory income for registered farmers and tobacco producers
	Lower threshold (BGN per month)								450
	Upper threshold (BGN per month)								3 000
	Total			
	Note:
	1. Employer contributions were added to market income 	
	2. We use EUROMOD assumption "It is assumed that all employees belong 
	to the 3rd category of labour."
*/

global s_pfb = 0.198
global s_pfa = 0.148+0.05
global s_smt = 0.035		
global s_hlt = 0.080

// born befor 1960
gen double cpn_csss_in    =ytcs_in*($s_pfb) if pb140 <1960 // pension  worker/employee  	
// born after 1959
replace cpn_csss_in=ytcs_in*($s_pfa) if pb140 >= 1959		
// evasion ???
replace cpn_csss_in=0 if cpn_csss_in==.  //?? minimum income???	
gen double con_smts_in    =ytcs_in*($s_smt) // sickness & maternity fund 	
gen double con_hlts_in	   =ytcs_in*($s_hlt) // health fund 

// check totals 

mat self2 =(  235.46,  27.92, 106.42) 
tabstat cpn_csss_in con_smts_in con_hlts_in [w=round(weight)], ///
stat(sum) col(stat) format(%18.0fc) save 
tabstatmat self1
mata: a=(st_matrix("self1"):/1000000):/st_matrix("self2")
mata: b=(a \ st_matrix("self1"):/1000000 \ st_matrix("self2"))
mata: st_matrix( "self3", b)					
mat colnames self3 = pens SicKMatF Health 
matlist self3, format(%12.2fc)

/*
             |         pens      SicKMatF        Health 
-------------+------------------------------------------
          r1 |         1.21          1.80          1.08 
          r2 |       284.58         50.31        114.98 
          r3 |       235.46         27.92        106.42 
*/

*----------3.5:  Label variables 

label var cpn_cssp_in "Contributions to pensions employer (individual)"
label var cpn_csse_in "Contributions to pensions employee (individual)"
label var cpn_csss_in "Contributions to pensions self-employed (individual)"

label var con_smtp_in "Contributions Gral Sickness & Maternity Fund employer (individual)"
label var con_smte_in "Contributions Gral Sickness & Maternity Fund employee (individual)"
label var con_smts_in "Contributions Gral Sickness & Maternity Fund self-employed (individual)"

label var con_wkip_in "Contributions Work Injury & Occup. Disease Fund (individual)"
label var con_unmp_in "Contributions Unemployment Fund employer (individual)"
label var con_unme_in "Contributions Unemployment Fund employee (individual)"

label var con_hltp_in "Contributions Health employer (individual)"
label var con_hlte_in "Contributions Health employee (individual)"
label var con_hlts_in "Contributions Health self-employed (individual)"

percap cpn_*_in con_*_in

rpayi cpn*_in con*_in 
tempvar cpn_total 
egen double `cpn_total' = rsum(cpn*pc con*_pc )
tabstat cpn*_pc con*_pc `cpn_total' [w=weight], stat(sum) format(%15.0fc) col(stat)

/*
    Variable |             Sum
	-------------+----------------
	cpn_csse_pc |   1,431,462,696
	cpn_cssp_pc |   1,796,665,024
	cpn_csss_pc |     137,736,947
	con_smte_pc |     228,251,455
	con_unme_pc |      65,214,701
	con_hlte_pc |     521,717,611
	con_smtp_pc |     342,377,182
	con_unmp_pc |      97,822,052
	con_wkip_pc |     114,125,727
	con_hltp_pc |     782,576,417
	con_smts_pc |      24,347,440
	con_hlts_pc |      55,651,292
    __000000 |   5,597,948,545
	------------------------------
	
	Contributions are slightly higher than nat accounts, 
	//  not scaled-down, difference is only 1%
	
*/

local tot_contributions = 6484770000  // from BG stats 
summ `cpn_total' [w=weight], meanonly
di %18.0fc r(sum)

local factor= r(sum)/ `tot_contributions'
di `factor'  // 1.00000275

/*
foreach var of varlist cpn*pc con*pc cpn*hh con*hh con*in cpn*in {
	replace `var' = `var' * `factor'
}	
*/

tempvar cpn_total2 
egen double `cpn_total2' = rsum(cpn*pc con*_pc )
tabstat cpn*_pc con*_pc `cpn_total2' [w=weight], stat(sum) format(%15.0fc) col(stat)

/*
	Employers' actual pension contributions (1)          3592.54
	Pensions Fund                                        3 592.54  1,925.0
	Employers' actual non-pension contributions (1)      2 820.35
	Common disease and Maternity Fund                      712.76  - 366.8
	Employment Injury and Occupational Disease Fund       228.91     104.8
	Unemployment Fund                                     203.61  -  122.3
	Employers' health insurance contributions            1675.08  -  838.5
*/


/*
	
	Compulsory households' actual social contributions                   4200.67
	Compulsory employees' actual social contributions                    3587.17
	Pensions Fund                                                        2068.20    1533.7
	Common disease and Maternity Fund                                     418.34    244.6
	Unemployment Fund                                                    119.50      69.9
	Employees' health insurance contributions                            981.14     559.0 
	
*/


/**
	Compulsory actual social contributions by the self-employed (1)       613.50
	Pensions Fund                                                        284.36   389.3
	Common disease and Maternity Fund                                     42.19    68.8
	Health insurance contributions by the self-employed                  286.96   157.3
	
*/


/*==================================================
	----------4: Market Income PDI 
==================================================*/	

summ y*pc 

/*
    Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
       yd_pc |     17,249     4390.13     5174.76    106.312   189189.9
       ym_pc |     17,249    4282.047    6346.647          0     207393
      ym2_pc |     17,249    3759.539     5946.37  -1278.249     204181
       ye_pc |     17,249    5226.252    6235.393          0     207393
*/	

tempvar cpn_total con_total 
egen double `cpn_total' = rsum(cpn_*p_in con_*p_in)
summ py030g `cpn_total'

/*
    Variable |        Obs        Mean    Std. dev.       Min        Max
-------------+---------------------------------------------------------
      py030g |     15,221    571.0021    1000.315          0   13492.18
    __000000 |     17,249    475.1119    810.8478          0   3537.785

*/	

tabstat py030g `cpn_total'  [w=weight], stat(sum) format(%15.0fc)
count if py030g > 0
// 9467
count if py030g > `cpn_total'
// 4366

/*
	py030g includes private programs, so there is another source of difference 
	with respect to estimated contributions to social security 
	
   Stats |          py030g        __000000
---------+--------------------------------
     Sum |   3,932,929,737   3,736,728,314
------------------------------------------
	
	Estimated contributions are lower than py030g 
	
	However, a new estimation is excluding contributing to family work 
	
	Employers’ social insurance contributions (PY030G): Employers’ contributions are 
	defined as payments made, during the income reference period, by employers 
	for the benefits of their employees to insurers (social security funds and 
	private funded schemes) covering statutory, conventional or contractual 
	contributions in respect of insurance against social risks.
	[ ] Employers’ contributions to private retirement (pension) plans;
	[ ] Employers’ contributions to private health insurance;
	[ ] Employers’ contributions to life insurance;
	[x] Employers’ contributions to other employer insurance schemes (e.g. disability);
	employers’ contributions to government insurance (social security) schemes(including 
	payroll taxes levied for social insurance purposes).
*/

egen double `con_total' = rsum(cpn*pc con*pc)
summ py030g `con_total' [w=weight], meanonly
di %18.0fc r(sum)


// adding employer contributions to market income 

tempvar py030g_hh py030g_pc tot_conp 

bysort hhid: egen `py030g_hh' = sum(py030g)
gen  double `py030g_pc' = `py030g_hh'/hsize 	
egen double `tot_conp' = rsum(c?n_???p_pc)

count if ym_pc + cpn_cssp_pc + con_smtp_pc + con_unmp_pc + ///
con_wkip_pc + con_hltp_pc - `py030g_pc' < `py030g_pc' 

foreach var of varlist cpn*pc con*pc {
	replace `var'=0 if ym_pc==0 
}

list hhid c?n_???p_pc `tot_conp' `py030g_pc' if ym_pc + cpn_cssp_pc + ///
con_smtp_pc + con_unmp_pc + con_wkip_pc + con_hltp_pc - ///
cpn_csse_pc - cpn_csss_pc - `py030g_pc' < 0, sepby(hhid)

replace ym_pc = ym_pc + cpn_cssp_pc + con_smtp_pc + con_unmp_pc + ///
con_wkip_pc + con_hltp_pc - `py030g_pc' if ym_pc!=0
replace ye_pc = ye_pc + cpn_cssp_pc + con_smtp_pc + con_unmp_pc + ///
con_wkip_pc + con_hltp_pc - `py030g_pc' if ym_pc!=0


summ y*_pc 

/*==================================================
	5:  Market income plus pensions PDI 
==================================================*/

*----------5.1: Market Income + P PDI 

gen yp_pc = ym_pc + pen_csss_pc - (cpn_csse_pc + cpn_cssp_pc + cpn_csss_pc)
label var yp_pc "Market income plus pensions PDI (Per capita)"
summ y*pc

tempvar yp_pc_lcu yp_ae_lcu  
gen `yp_pc_lcu' = yp_pc*px010
gen `yp_ae_lcu'		= (`yp_pc_lcu'*hsize)/hx050

ainequal yp_pc ym_pc [w=round(weight)] if memb_no==1

povcc `yp_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
povcc `yp_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
povcc `yp_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62) 		
povcc `yp_ae_lcu'     [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 	

/*
. povcc `yp_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
ppp 1.9:  3.25, official:  0.25

. povcc `yp_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
ppp 3.2:  5.01, official:  1.36

. povcc `yp_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62)           
ppp 5.5:  7.93, official:  3.62

. povcc `yp_ae_lcu'     [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1)       
National: 25.34, official: 22.10

*/


/*==================================================
	6:  Household variables 
==================================================*/

gen urban=inlist(db100,1,2)

label var urban       "Living in urban area"
label define urban 0  "Rural" 1 "Urban"
label val urban urban
notes urban: rural is thinly-populated area

label var hhid "Household identifier"
label var hsize "Household size"

cap drop _*		
save "${tmp}BGR20_mpp_inc.dta", replace 

cap log close
/* End of do-file */

exit 

/*

 Household |        ytcw_in
identifier |         0   3742.714 |     Total
-----------+----------------------+----------
   2901000 |         5          1 |         6 
   3443100 |         0          1 |         1 
   3908200 |         1          1 |         2 
   3908500 |         1          1 |         2 
-----------+----------------------+----------
     Total |         7          4 |        11 
*/	



><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><
Version Control: 
2.2 Update totals in contributions, not scaled-down 
2.1 Update rates and min/max for contributions 

Notes: 
------------------	
1. Government employees  (ok!)
2. Rates (ok!)
3. Check totals in pensions (actuals)  OK  4% +
3. Check totals in pensions (beneficiaries)  3% -
4. Check totals in contributions (actuals, per scheme)  1% +
