/*==================================================
	project:       CEQ Bulgaria  2020
	Author:        Cabrera 
	E-email:       maynor.cabrera@ceqinstitute.org
	url:           
	Dependencies:  World Bank 
	Input files 
	- BGR20_mpp_inc.dta
	
	Output files:
	- BGR20_net_inc.dta 
	----------------------------------------------------
	Creation Date:       10 Dec 2021
	Modification Date:   29 Apr 2023
	Do-file version:    2.1
	
	References:          	
	- Euromod Bulgaria Report 
	Tosheva, E., Tasseva, I., Dimitrova, D. Draganov, D. & V. Boshnakov (2022),  
	“Euromod Country Report Bulgaria BULGARIA (BG) 2019-2022” 
	
================================================== */


/*==================================================
	0: Options
==================================================*/

global pit_rate = 0.10
global int_rate = 0.08

/*==================================================
	1: Family members 
==================================================*/

use "${tmp}BGR20_mpp_inc.dta", clear
cap drop _*
gen child = (age<18)
bysort hhid: egen s_py130g = sum(py130g)
gen disab = (s_py130g>0) & child 

preserve 
collapse (sum) child disab, by(rb220)
rename rb220 hhin
rename child child_f
rename disab disab_f
drop if hhin==" "
destring hhin, replace 
sort hhin
save "${tmp}father.dta" , replace 

restore 

collapse (sum) disab child, by(rb230)
rename rb230 hhin
rename child child_m
rename disab disab_m
drop if hhin==" "
destring hhin, replace 
sort hhin
save "${tmp}mother.dta" , replace 

/*==================================================
	2: Taxable Income 
==================================================*/

local cfi = substr(c(filename),ustrlen("${tmp}")+1,11)
if "`cfi'" != "BGR20_mpp_inc" | c(changed)==1 {
	use "${tmp}BGR20_mpp_inc.dta", clear
}

/* */
cap drop _*

merge 1:1 hhin using "${tmp}father.dta" 
drop if _merge==2
drop _*

merge 1:1 hhin using "${tmp}mother.dta" 
drop if _merge==2
drop _*

*----------2.1: Gross Income 
recast double py010g py020g py050g hy040g

egen double ytp_in = rsum(py010g py020g py050g)

tempvar ytpp_in 

gen  double `ytpp_in' = hy040g if memb_no==1  // Income from rental of a property or land

replace `ytpp_in'=0 if  `ytpp_in'==.

misstable summ `ytpp_in'

replace ytp_in = ytp_in + `ytpp_in'  // I. Income from all source 	
gen double ytpi_in = hy090g if memb_no==1 // I.1 Interest, dividends, profit from capital
// Interest is taxed at a different rate than other income sources


*----------2.2: Deductions 

** 1.2.1 labor contract 
tempvar labinc selfinc 
gen `labinc'=1  if py010g>0 & py010g<. & informal_w==0

** 1.2.2 Self employed 
gen `selfinc'=1 if py050g>0 & py050g<. & informal_s==0 //

/*
	 Freelance professions 25%
	 Agricultural activity (processed products) 40-60%
	 Forestry and fishery activity 40%
	 Income from crafts, trade with decorative plants 40%
	 Artistic/performance activities 40%
	 Income from authorship rights (scientific/art products) 40%
*/

global sh_nre  = 0.25  // freelance  
global sh_nre2 = 0.40  // asumming 40% for agriculture 
global sh_nre3 = 0.10  // other - real state nonfin assets 

gen double nre = (py050g*max(pl075, pl076))/12*$sh_nre 

/*
92	"Agricultural, forestry and fishery labourers"                     ///
61	"Market-oriented skilled agricultural workers"                      ///
62	"Market-oriented skilled forestry, fishery and hunting workers"     ///
*/

**only agricultural, forestry and fishery 
	**artistic mixed with legal, social. So not included  (keep as gral rate)
**authorship products (same as above)

replace nre = (py050g*max(pl075, pl076))/12*$sh_nre2 if inlist(pl051a,92, 61,62)
replace nre = max(0,nre) + (`ytpp_in')*$sh_nre3
replace nre = 0 if nre ==.

*----------2.2: Tax Base 

tab `labinc' `selfinc', m	

gen double    ytp2_in = ytp_in - cpn_csse_in - con_hlte_in - con_smte_in - con_unme_in ///
if `labinc'==1 & `selfinc'==.

replace ytp2_in = ytp_in - cpn_csss_in - con_hlts_in - con_smts_in - nre ///
if `selfinc'==1 & `labinc'==.

replace ytp2_in = ytp_in - cpn_csss_in - con_hlts_in - con_smts_in - nre - ///
cpn_csse_in - con_hlte_in - con_smte_in - con_unme_in ///
if `selfinc'==1 & `labinc'==1

summ yt*2_in 

*----------2.3: Allowances 

** 2.3.1 Rates 

global r_dis   = 0.5
global max_dis = 7920/px010 
global a_chd   = 200/px010
global max_chd = 600/px010
global dis_chd = (2000)/px010

*2.31 Standard deduction for permantly disabled
gen double disab_allowance = min(ytp2_in*$r_dis,$max_dis) if ph030==1 & ph020==1
replace disab_allowance = 0 if disab_allowance==.

*2.3.2 Deduction for voluntary social, unemployment, health and life 
	*	insurance (max.% from the consolidated tax base)  NOT INCLUDED 
*2.3.3. Standard child deduction
gen double child_allowance = min(($a_chd)*child_f, $max_chd) 
replace    child_allowance = max(0,child_allowance) + ($dis_chd) if disab_f>0 & disab_f<.
replace    child_allowance = max(min(($a_chd)*child_m, $max_chd), child_allowance)
replace    child_allowance = max(0,child_allowance) + ($dis_chd) if disab_m>0 & disab_m<.
replace    child_allowance = 0 if child_allowance ==.

*2.3.4. Deduction of bequests NOT INCLUDED 

*  ----------2.4 Taxable income 
gen double ytp3_in = ytp2_in - disab_allowance - child_allowance
replace ytp3_in =0 if ytp3_in==. | ytp3_in<0	

/*==================================================
	3: Personal Income Tax 
==================================================*/

gen double dtx_pitx_in = ytp3_in * $pit_rate 
gen double dtx_piti_in = ytpi_in * $int_rate 

label var dtx_pitx_in "Personal Income Tax (individual)"
label var dtx_piti_in "Personal Income Tax - interest (individual)"

percap dtx_piti_in dtx_pitx_in 
rpayi  dtx_piti_in dtx_pitx_in 	

/*==================================================
	4: Net Market Income 
==================================================*/

gen double yn_pc= yp_pc - (dtx_piti_pc + dtx_pitx_pc + con_smte_pc + ///
con_hlte_pc + con_unmp_pc + con_hltp_pc + con_hlts_pc + con_unme_pc + ///
con_smtp_pc + con_wkip_pc + con_smts_pc)

** negatives 
count if yn_pc<0	

**replace dtx_pitx_pc =0 if yn_pc<0
** replace yn_pc =0 	   if yn_pc<0	

label var yn_pc "Net Market Income PDI (per capita)"

summ ym_pc  yp_pc yn_pc
/*
	Variable |        Obs        Mean    Std. dev.       Min        Max
	-------------+---------------------------------------------------------
	ym_pc |     17,012    4069.889    5167.498          0   180560.5
	yp_pc |     17,012    4396.867    4715.127   14.94818     176916
	yn_pc |     17,012    3843.381    4110.549   14.94818   157158.8
*/


tempvar yn_pc_lcu yn_ae_lcu 
gen  `yn_pc_lcu' = yn_pc*px010
gen  `yn_ae_lcu' = (`yn_pc_lcu'*hsize)/hx050
summ `yn_pc_lcu'

ainequal yn_pc ym_pc [w=round(weight)] if memb_no==1

povcc `yn_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
povcc `yn_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
povcc `yn_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62) 
povcc `yn_ae_lcu'  [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 	

/*
---------------------------------------------------
       Inequality measures |      yn_pc       ym_pc
---------------------------+-----------------------
          Gini coefficient |    0.43663     0.60106
Theil index (GE(a), a = 1) |    0.39699     0.87308
---------------------------------------------------

. 
. povcc `yn_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.25) 
ppp 1.9:  3.37, official:  0.25

. povcc `yn_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(1.36) 
ppp 3.2:  5.26, official:  1.36

. povcc `yn_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(3.62) 
ppp 5.5:  9.27, official:  3.62

. povcc `yn_ae_lcu'  [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1)  
National: 30.58, official: 22.10
	
*/	


/*==================================================
	6:  Clean & save file  
==================================================*/


save "${tmp}BGR20_net_inc.dta", replace 


cap log close
exit
/* End of do-file */


><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><

Notes:
1. Tax relief measures?
2. No. taxpayers?
3. Totals 

Version Control: 1

Changes 
------------------
2.1 Rates / Allowances 



