capture log close
log using "${log}5_BGR_IndTaxes.txt", replace text
/*==================================================
	project:       CEQ Bulgaria
	Author:        Cabrera, M. 
	E-email:       
	url:           
	Dependencies:  World Bank
	----------------------------------------------------
	Creation Date:    11 Apr 2023 
	Modification Date:   
	Do-file version:    02
	References:          
	Output:             dotemplate.ado
==================================================*/

/*==================================================
	0: Program set up
==================================================*/
version 15
drop _all
global xlmip_2014   "${tmp}io_2014.xlsx"
global xlmip_2010   "${tmp}io_2010.xlsx"
global ctec   		"${tmp}ctaugio_2014.xlsx"
global simulations  "$escen_0" 
global io_version   "2010"

// check changes ## below 


/*==================================================
	1: I-O table & indirect effects 
==================================================*/


*----------1.1: Retrieve IO matrix 

use "${tmp}bgr_io${io_version}.dta", clear 


*----------1.2: Create technical coefficients
drop if mipcat==0 
mkmat prod01-prod62, matrix(A)  // IO converted to matrix 
// creating 2 fictional activities following VAT methodology 
// for Fiji to have exempt - non exempt 

/*
mata:
p0=st_matrix("p")    				// input matrix to mata 
p1=rows(p0)							// technical coefficients estimation
p2=p1-3
ct=p0[1::p2,]:/p0[p1,]				// p0 row is total production 

st_matrix("A",ct)  				// export from mata to stata 

end
*/

*----------1.3: Reading matrix from IO Table 

/* Product description in IO Matrix 
	
*/	

* Matrix with sectors splitted in 2 

local Nsectors=rowsof(A)
di `Nsectors'


*----------1.4: Introduce changes  ##

/*
	Methodology- Indirect Effects for Subsidies 
	
	Based on Inchauste & Jellema (2018)
	
*/

scalar ele_sub  = round(0.107/0.126, 0.1)   // subsidy divided by consumer price 
scalar gas_sub  = round(3.03 /8.03,0.1)     // subsidy divided by consumer price 

/*
						Unit		Consumer Price	Supply Cost	Explicit subsidy - per unit	

Natural gas - industrial	LCU / GJ		8.03			11.06		3.03	
Electricity - industrial	LCU / kWh	0.126		0.23			0.107

*/	


** source of subsidy IMF fuel subsidies template 2021

** asumming only indirect effects for industrial & power 

local fix_price_ele 1 2 3 4 ///
	26 27 28 29  ///
	30 31 32 33 34 35 36 37 38 39  ///
	40 41 42 43 44 45 46 47 48 49  ///
	50 51 52 53 54 55 56 57 58 59  ///
	60 61 62

local fix_price_gas 1 2 3 4 ///
	26 27 28 29  ///
	30 31 32 33 34 35 36 37 38 39  ///
	40 41 42 43 44 45 46 47 48 49  ///
	50 51 52 53 54 55 56 57 58 59  ///
	60 61 62

local price_shock_ele 24

local price_shock_gas 24

local indeff ele gas // indirect effects for indirect taxes 


*----------1.5: Compute indirect price effects, based on the Cost-Push Model

foreach sim of local indeff {	
	
	matrix dp_sim`sim' = J(1,`Nsectors',0)
	*foreach x of local fix_price_`sim' {
	mat dp_sim`sim'[1,`price_shock_`sim'']=`sim'_sub
	
	
	matrix gamma_`sim'=J(`Nsectors',`Nsectors',0)  // initializes fixed price matrix 
	** Specify the row/column numbers of the commodities whose price will be fixed                                                           
	foreach row of numlist `fix_price_`sim'' {                       
		matrix gamma_`sim'[`row',`row']=1                  
	}
	** Calculating cost-push model pass-through for prices of all sectors
	matrix alpha_`sim' = I(`Nsectors') - gamma_`sim'                                          
	// Here we have the Inverse Leontief Coefficients               
	matrix V_`sim'     = inv(I(`Nsectors') - alpha_`sim' * A)   
	*
	matrix deltaptilda_`sim' = dp_sim`sim' * A * V_`sim'                                   
	matrix deltap_`sim'      =(dp_sim`sim' *gamma_`sim') + ///
	(deltaptilda_`sim'+dp_sim`sim') * alpha_`sim'   
	
	*
	** Output simulated price shock and price pass-through on all sectors 
	dis "simulated price increases "                         
	matrix list dp_sim`sim'                                               
	dis "fixed price sectors: gamma"                                  
	matrix list gamma_`sim'                                                 
	dis "Indirect effect price increase"                              
	matrix list deltaptilda_`sim'                                           
	dis "total price increase"                                        
	matrix list deltap_`sim'	
	
	** This loop generates price variables for price changes by sector         
	foreach sector of numlist 1/`Nsectors' {                          				
		gen double st`sim'_`sector'=deltap_`sim'[1,`sector']  // stot 
		label var  st`sim'_`sector' "total price inc. `sim' tax for sector `sector'"			
		gen double si`sim'_`sector'=deltaptilda_`sim'[1,`sector'] // sind 
		label var  si`sim'_`sector' "indirect tprice inc. `sim' tax for sector `sector'"			
		gen double sd`sim'_`sector'= st`sim'_`sector'- si`sim'_`sector'
		label var  sd`sim'_`sector' "direct tprice inc. `sim' tax for sector `sector'"		
	}	
}

rename mipcat sector 
keep sector st* si* sd* 
ren sector s 

reshape long  stele_ siele_ sdele_ stgas_ sigas_ sdgas_, i(s) j(sector)
drop s 
duplicates drop 
sort sector
rename sector sector2
sort sector2
compress	


sum si*  //OK: Average Indirect effect is 4.3% 

rename sector2 sector1

save "${tmp}seffects.dta", replace 


*----------1.6: Merge indirect effects & rates 

use "${tmp}tasas_itx.dta", clear

gen sector1 = io_code 

merge m:1 sector1 using "${tmp}seffects.dta"

tabstat st*, by(sector1)

list  sector1 if _merge==2
drop if _merge==2
drop _merge 

sort cod_subclass
save "${tmp}tasas_sub.dta", replace 

/*==================================================
	2: Subsidies estimation 
	==================================================*/

use "${tmp}hsb_coicop.dta", clear 
merge m:1 cod_subclass using "${tmp}tasas_sub.dta", keep(master match)


*----------2.1: Electricity 

/*
	
	assumming the consumption is annual 
	
			2020H1	2020H2	2021H1	2021H2
Group E1 (annual electricity consumption by household customers < 1 000 kWh)	levs per kilowatt hour	
0.2022	0.2042	0.2076	0.2189  0-  213.25 
Group E2 (annual electricity consumption by household customers1 000 < 2 500 kWh)	levs per kilowatt hour	
0.1990	0.1996	0.2043	0.2160 213.26 - 528.47
Group D3 (annual electricity consumption by household customers 2 500 < 5 000 kWh)	levs per kilowatt hour	
0.1950	0.1920	0.2002	0.2133 528.48 -1045.35
Group D4 (annual electricity consumption by household customers 5 000 < 15 000 kWh	levs per kilowatt hour	
0.1882	0.1866	0.1934	0.2124  1045.36 - 3074.35
Group D5 (annual electricity consumption by household customers >= 15 000 kWh)	levs per kilowatt hour	
0.1823	0.1857	0.1851	0.2110  3074.36+


https://infostat.nsi.bg/infostat/pages/reports/query.jsf?x_2=518

*/

gen double expen_bgn = expen*EXR

mat aexp_2021 = (213.25, 528.475, 1045.35, 3074.35)
mat texp_2021 = (0.2133, 0.2102, 0.2068, 0.2029, 0.1981)
mat slab_2021 = (1000, 2500, 5000, 15000)


gen group_elec = .
replace group_elec = 1 if expen_bgn<aexp_2021[1,1] & cod_subclass=="04510"
replace group_elec = 2 if inrange(expen_bgn,aexp_2021[1,1], aexp_2021[1,2]) & cod_subclass=="04510"
replace group_elec = 3 if inrange(expen_bgn,aexp_2021[1,2], aexp_2021[1,3]) & cod_subclass=="04510"
replace group_elec = 4 if inrange(expen_bgn,aexp_2021[1,3], aexp_2021[1,4]) & cod_subclass=="04510"
replace group_elec = 5 if expen_bgn>aexp_2021[1,4] & cod_subclass=="04510"

scalar supply_cost = 0.1482  // Euros IMF 

// prices source https://infostat.nsi.bg/infostat/pages/reports/result.jsf?x_2=518
replace quant = expen_bgn / texp_2021[1,1] if group_elec==1 & cod_subclass=="04510"
replace quant = slab_2021[1,1] + (expen_bgn - aexp_2021[1,1]) / texp_2021[1,2] if group_elec==2 & cod_subclass=="04510"
replace quant = slab_2021[1,2] + (expen_bgn - aexp_2021[1,2])/ texp_2021[1,3] if group_elec==3 & cod_subclass=="04510"
replace quant = slab_2021[1,3] + (expen_bgn - aexp_2021[1,3])/ texp_2021[1,4] if group_elec==4 & cod_subclass=="04510"
replace quant = slab_2021[1,4] + (expen_bgn - aexp_2021[1,4])/ texp_2021[1,4] if group_elec==2 & cod_subclass=="04510"


gen double sub_eled_hh = 0
** prices without taxes 
replace sub_eled_hh = (supply_cost - (0.1651/EXR))*quant if cod_subclass=="04510" & group_elec==1
replace sub_eled_hh = (supply_cost - (0.1651/EXR))*quant if cod_subclass=="04510" & group_elec==2
replace sub_eled_hh = (supply_cost - (0.1651/EXR))*quant if cod_subclass=="04510" & group_elec==3
replace sub_eled_hh = (supply_cost - (0.1651/EXR))*quant if cod_subclass=="04510" & group_elec==4
replace sub_eled_hh = (supply_cost - (0.1651/EXR))*quant if cod_subclass=="04510" & group_elec==5

gen double sub_elei_hh = expen*siele_


*----------2.2:  Gas 

gen double sub_gasd_hh = expen*(srategas) if cod_subclass=="04521"
gen double sub_gasi_hh = expen*sigas_

tempfile hhd1 
collapse (sum) expen consm sub* (mean) psu weight strata, by(hhid)

sort hhid 
save `hhd1', replace 

	import excel using "${raw}HBS/2021 HBS/Data/Basic_HBS_2021/hm_basic_2021_HBS_BG.xlsx", clear firstrow
	rename *, lower 


rename ma04 hhid 
rename ma05 id 
rename mb02 gender // 1 male 2 female 
rename mb03 age 
rename mb04 marital_status // 1  Never married 2  Married 3  Widowed 4  Divorced 9  Not specified
rename mb042 partners // Partners living in the same household
rename mb05 relation 

merge m:1 hhid using "`hhd1'"

drop if relation=="6"

bysort hhid: gen hsize = _N 

gen double cons_pc = expen / hsize 

xtile centyd = cons_pc [w=weight], nq(100)

foreach x of varlist sub_*_hh {
	gen double sh_`x' = `x'/expen
}


lowess sh_sub_eled_hh centyd  , adjust gen(rats_eled)  nograph
lowess sh_sub_elei_hh centyd  , adjust gen(rats_elei)  nograph
lowess sh_sub_gasd_hh centyd  , adjust gen(rats_gasd)  nograph
lowess sh_sub_gasi_hh centyd  , adjust gen(rats_gasi)  nograph

recast double rats*

foreach var of varlist rats* {
	
	recode `var' (min/0=0)
}	

collapse (median) rats* [w=weight], by(centyd)
save "${tmp}sub_centile.dta", replace 

*twoway (line rats_gasd centyd) (line rats_gasi centyd)
*twoway (line rats_eled centyd) (line rats_elei centyd)

/*==================================================
3:  Impute results in EU_SILC survey 
==================================================*/


*----------3.1: open BGR disposable income 
use "${tmp}BGR20_cons1_inc.dta" ,clear 

*----------3.3: merge shares of subsidies 

merge  m:1 centyd using "${tmp}sub_centile.dta"

*----------3.4: estimate subsidies 

cap drop yd_hh 
bysort hhid: egen double yd_hh=sum(yd_pc)

foreach x of varlist rats* {
	local sub = subinstr("`x'","rats_","",.)
	local sub = "sub_`sub'_hh"
	gen double 	`sub' = yd_hh*`x'	
}

label var sub_gasd_hh "Indirect subsidies: Gas direct effects (household)"
label var sub_gasi_hh "Indirect subsidies: Gas indirect effects (household)"
label var sub_eled_hh "Indirect subsidies: Electricity direct effects (household)"
label var sub_elei_hh "Indirect subsidies: Electricity indirect effects (household)"

percap s*hh 

foreach var of varlist sub_*_pc {
	local rhh = subinstr("`var'","_pc","_rh",1)
	gen int `rhh' = (`var'>0 & memb_no==1)
}

lab_torh sub_*_rh 

/*
Select country		Bulgaria	
Select year		2020	
Unit				Millions		
Currency			LCU		
			
Total subsidies - selected country			
			Unit				Explicit
Natural gas	LCU Millions		380.4



Electricity	LCU Millions		3,544.3

*/

scalar SUB_NGAS =  (113.137681+380.384448)*1000000/EXR  // 2020 gas  ##

summ sub_gasd_pc [w=weight], meanonly 
local gasd = r(sum)
summ sub_gasi_pc [w=weight], meanonly 
local gasi = r(sum)

// local ratgas = SUB_NGAS / (`gasd' + `gasi')
// table 'All_Explicit'
local ratgasd = SUB_NGAS*(7/29)  / (`gasd')
local ratgasi = SUB_NGAS*(22/29) / (`gasi')

di  %15.0fc (`gasd' + `gasi')/1000000
di `ratgasi' 
di `ratgasd' 
di  as text "Direct  " as result %15.0fc (`gasd' )/1000000
di  as text "Indirect" as result %15.0fc (`gasi' )/1000000

replace sub_gasi_hh =  sub_gasi_hh * `ratgasi'
replace sub_gasi_pc =  sub_gasi_pc * `ratgasi'
replace sub_gasd_hh =  sub_gasd_hh * `ratgasd'
replace sub_gasd_pc =  sub_gasd_pc * `ratgasd'

scalar SUB_ELEC = 3544336990/EXR //  2020 elec ##

summ sub_eled_pc [w=weight], meanonly 
local eld = r(sum)
summ sub_elei_pc [w=weight], meanonly 
local eli = r(sum)

// local ratele = SUB_ELEC / (`eld' + `eli')

local rateled = SUB_ELEC*(0.979/2.068) / (`eld')
local ratelei = SUB_ELEC*(1.089/2.068) / (`eli')

di `ratele'
di  %15.0fc (`eld' + `eli')/1000000
di  as text "Direct  " as result %15.0fc (`eld' )/1000000
di  as text "Indirect" as result %15.0fc (`eli' )/1000000


replace sub_elei_hh =  sub_elei_hh * `ratelei'
replace sub_elei_pc =  sub_elei_pc * `ratelei'
replace sub_eled_hh =  sub_eled_hh * `rateled'
replace sub_eled_pc =  sub_eled_pc * `rateled'

di `rateled' "--" `ratelei'
di `ratgasd' "--" `ratgasi'


*----------3.5: check if there are negatives 
cap drop _*
tempvar tot_itx tmp_yc tot_sub 

egen double `tot_itx' = rsum(itx_vatx_pc  itx_oild_pc  itx_oili_pc  itx_beve_pc  itx_toba_pc)
replace `tot_itx' = `tot_itx'*-1

egen double `tot_sub' = rsum(sub*pc)

egen double yc_pc = rsum(yd_pc `tot_itx' `tot_sub')

label var yc_pc "Consumable Income (per capita)"

gen itx_car2_pc = itx_carb_pc*-1  // to not adding the carb taxes to the totals of indirect taxes 

summ yc_pc 

*----------5.6: check poverty and inequality 

ainequal ym_pc  yd_pc yc_pc [w=round(weight)] 
	
	scalar PL190 = .8453251*1.90*365
	scalar PL320 = .8453251*3.20*365
	scalar PL550 = .8453251*5.50*365
	
	cap drop _*
	tempvar yc_pc_lcu 	yc_ae_lcu 
	gen `yc_pc_lcu' = yc_pc*px010
	gen  `yc_ae_lcu' = (`yc_pc_lcu'*hsize)/hx050	
	summ `yc_pc_lcu'
	
	di PNATM 
	
	cap drop if yd_pc==.
	
	tempvar yd_pc_lcu yd_ae_lcu  
	gen `yd_pc_lcu' = yd_pc*px010
	gen  `yd_ae_lcu' = (`yd_pc_lcu'*hsize)/hx050	
	summ `yd_pc_lcu'
	
	povcc `yc_pc_lcu'  [fw=round(weight)], pline(PL190) nn("ppp 1.9")  ppof(0.87) 
	povcc `yc_pc_lcu'  [fw=round(weight)], pline(PL320) nn("ppp 3.2")  ppof(2.16) 
	povcc `yc_pc_lcu'  [fw=round(weight)], pline(PL550) nn("ppp 5.5")  ppof(6.90) 		
	
	povcc `yc_ae_lcu'  [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 	
	povcc `yd_ae_lcu'  [fw=round(weight)], pline(PNATM) nn("National")  ppof(22.1) 	
	

/*==================================================
	6:  Save file - part of consumable income 
==================================================*/


save "${tmp}BGR20_cons2_inc.dta", replace 


log close
exit
/* End of do-file */

><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><

Notes:
1. It will be nice to have separation between electricity and gas
2.
3.


Version Control:


